@@ -15,13 +15,15 @@
 import logging
 from typing import Any, Dict, List, Optional
 from datetime import datetime as python_datetime
+from requests import Response
 
+from qiskit_ibm_provider.utils.hgp import from_instance_format
 from qiskit_ibm_runtime.api.session import RetrySession
 
 from .backend import BaseBackendClient
 from ..rest.runtime import Runtime
 from ..client_parameters import ClientParameters
-from ...utils.hgp import from_instance_format
+
 
 logger = logging.getLogger(__name__)
 
@@ -41,7 +43,7 @@ class RuntimeClient(BaseBackendClient):
         self._session = RetrySession(
             base_url=params.get_runtime_api_base_url(),
             auth=params.get_auth_handler(),
-            **params.connection_parameters()
+            **params.connection_parameters(),
         )
         self._api = Runtime(self._session)
 
@@ -126,6 +128,7 @@ class RuntimeClient(BaseBackendClient):
         max_execution_time: Optional[int] = None,
         start_session: Optional[bool] = False,
         session_time: Optional[int] = None,
+        channel_strategy: Optional[str] = None,
     ) -> Dict:
         """Run the specified program.
 
@@ -141,6 +144,7 @@ class RuntimeClient(BaseBackendClient):
             max_execution_time: Maximum execution time in seconds.
             start_session: Set to True to explicitly start a runtime session. Defaults to False.
             session_time: Length of session in seconds.
+            channel_strategy: Error mitigation strategy.
 
         Returns:
             JSON response.
@@ -160,7 +164,8 @@ class RuntimeClient(BaseBackendClient):
             max_execution_time=max_execution_time,
             start_session=start_session,
             session_time=session_time,
-            **hgp_dict
+            channel_strategy=channel_strategy,
+            **hgp_dict,
         )
 
     def program_delete(self, program_id: str) -> None:
@@ -201,7 +206,7 @@ class RuntimeClient(BaseBackendClient):
                 spec=spec,
             )
 
-    def job_get(self, job_id: str) -> Dict:
+    def job_get(self, job_id: str, exclude_params: bool = None) -> Dict:
         """Get job data.
 
         Args:
@@ -210,7 +215,7 @@ class RuntimeClient(BaseBackendClient):
         Returns:
             JSON response.
         """
-        response = self._api.program_job(job_id).get()
+        response = self._api.program_job(job_id).get(exclude_params=exclude_params)
         logger.debug("Runtime job get response: %s", response)
         return response
 
@@ -321,7 +326,7 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.program_job(job_id).logs()
 
-    def job_metadata(self, job_id: str) -> str:
+    def job_metadata(self, job_id: str) -> Dict[str, Any]:
         """Get job metadata.
 
         Args:
@@ -332,21 +337,42 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.program_job(job_id).metadata()
 
-    def close_session(self, session_id: str) -> None:
-        """Close the runtime session.
+    def cancel_session(self, session_id: str) -> None:
+        """Close all jobs in the runtime session.
 
         Args:
             session_id: Session ID.
         """
+        self._api.runtime_session(session_id=session_id).cancel()
+
+    def close_session(self, session_id: str) -> None:
+        """Update session so jobs can no longer be submitted."""
         self._api.runtime_session(session_id=session_id).close()
 
-    def list_backends(self, hgp: Optional[str] = None) -> List[str]:
+    def session_details(self, session_id: str) -> Dict[str, Any]:
+        """Get session details.
+
+        Args:
+            session_id: Session ID.
+
+        Returns:
+            Session details.
+        """
+        return self._api.runtime_session(session_id=session_id).details()
+
+    def list_backends(
+        self, hgp: Optional[str] = None, channel_strategy: Optional[str] = None
+    ) -> List[str]:
         """Return IBM backends available for this service instance.
 
+        Args:
+            hgp: Filter by hub/group/project.
+            channel_strategy: Filter by channel strategy.
+
         Returns:
             IBM backends available for this service instance.
         """
-        return self._api.backends(hgp=hgp)["devices"]
+        return self._api.backends(hgp=hgp, channel_strategy=channel_strategy)["devices"]
 
     def backend_configuration(self, backend_name: str) -> Dict[str, Any]:
         """Return the configuration of the IBM backend.
@@ -385,9 +411,7 @@ class RuntimeClient(BaseBackendClient):
         Raises:
             NotImplementedError: If `datetime` is specified.
         """
-        if datetime:
-            raise NotImplementedError("'datetime' is not supported with cloud runtime.")
-        return self._api.backend(backend_name).properties()
+        return self._api.backend(backend_name).properties(datetime=datetime)
 
     def backend_pulse_defaults(self, backend_name: str) -> Dict:
         """Return the pulse defaults of the IBM backend.
@@ -399,3 +423,15 @@ class RuntimeClient(BaseBackendClient):
             Backend pulse defaults.
         """
         return self._api.backend(backend_name).pulse_defaults()
+
+    def update_tags(self, job_id: str, tags: list) -> Response:
+        """Update the tags of the job.
+
+        Args:
+            job_id: The ID of the job.
+            tags: The new tags to be assigned to the job.
+
+        Returns:
+            API Response.
+        """
+        return self._api.program_job(job_id).update_tags(tags)
