@@ -15,7 +15,7 @@
 from typing import Dict, Any, Optional
 from concurrent import futures
 
-from .base import RestAdapterBase
+from qiskit_ibm_provider.api.rest.base import RestAdapterBase
 from ..session import RetrySession
 
 
@@ -32,9 +32,7 @@ class Program(RestAdapterBase):
 
     _executor = futures.ThreadPoolExecutor()
 
-    def __init__(
-        self, session: RetrySession, program_id: str, url_prefix: str = ""
-    ) -> None:
+    def __init__(self, session: RetrySession, program_id: str, url_prefix: str = "") -> None:
         """Job constructor.
 
         Args:
