@@ -17,12 +17,13 @@ from datetime import datetime
 from typing import Dict, Any, List, Union, Optional
 import json
 
-from .base import RestAdapterBase
-from .program import Program
-from .program_job import ProgramJob
+from qiskit_ibm_provider.api.rest.base import RestAdapterBase
+from qiskit_ibm_provider.api.rest.program_job import ProgramJob
+from qiskit_ibm_provider.utils import local_to_utc
 from .runtime_session import RuntimeSession
+
+from .program import Program
 from ...utils import RuntimeEncoder
-from ...utils.converters import local_to_utc
 from .cloud_backend import CloudBackend
 
 logger = logging.getLogger(__name__)
@@ -138,6 +139,7 @@ class Runtime(RestAdapterBase):
         max_execution_time: Optional[int] = None,
         start_session: Optional[bool] = False,
         session_time: Optional[int] = None,
+        channel_strategy: Optional[str] = None,
     ) -> Dict:
         """Execute the program.
 
@@ -155,6 +157,7 @@ class Runtime(RestAdapterBase):
             max_execution_time: Maximum execution time in seconds.
             start_session: Set to True to explicitly start a runtime session. Defaults to False.
             session_time: Length of session in seconds.
+            channel_strategy: Error mitigation strategy.
 
         Returns:
             JSON response.
@@ -183,6 +186,8 @@ class Runtime(RestAdapterBase):
             payload["hub"] = hub
             payload["group"] = group
             payload["project"] = project
+        if channel_strategy:
+            payload["channel_strategy"] = channel_strategy
         data = json.dumps(payload, cls=RuntimeEncoder)
         return self.session.post(url, data=data, timeout=900).json()
 
@@ -266,17 +271,25 @@ class Runtime(RestAdapterBase):
         return CloudBackend(self.session, backend_name)
 
     def backends(
-        self, hgp: Optional[str] = None, timeout: Optional[float] = None
+        self,
+        hgp: Optional[str] = None,
+        timeout: Optional[float] = None,
+        channel_strategy: Optional[str] = None,
     ) -> Dict[str, List[str]]:
         """Return a list of IBM backends.
 
         Args:
+            hgp: The service instance to use, only for ``ibm_quantum`` channel, in h/g/p format.
             timeout: Number of seconds to wait for the request.
+            channel_strategy: Error mitigation strategy.
 
         Returns:
             JSON response.
         """
         url = self.get_url("backends")
+        params = {}
         if hgp:
-            return self.session.get(url, params={"provider": hgp}).json()
-        return self.session.get(url, timeout=timeout).json()
+            params["provider"] = hgp
+        if channel_strategy:
+            params["channel_strategy"] = channel_strategy
+        return self.session.get(url, params=params, timeout=timeout).json()
