@@ -24,10 +24,17 @@ from qiskit.providers.backend import BackendV1 as Backend
 from qiskit.providers.provider import ProviderV1 as Provider
 from qiskit.providers.exceptions import QiskitBackendNotFoundError
 from qiskit.providers.providerutils import filter_backends
+from qiskit.providers.models import (
+    PulseBackendConfiguration,
+    QasmBackendConfiguration,
+)
 
+from qiskit_ibm_provider.proxies import ProxyConfiguration
+from qiskit_ibm_provider.utils.hgp import to_instance_format, from_instance_format
+from qiskit_ibm_provider.utils.backend_decoder import configuration_from_server_data
 from qiskit_ibm_runtime import ibm_backend
-from .accounts import AccountManager, Account, AccountType, ChannelType
-from .proxies import ProxyConfiguration
+
+from .accounts import AccountManager, Account, ChannelType
 from .api.clients import AuthClient, VersionClient
 from .api.clients.runtime import RuntimeClient
 from .api.exceptions import RequestsApiError
@@ -43,29 +50,15 @@ from .hub_group_project import HubGroupProject  # pylint: disable=cyclic-import
 from .program.result_decoder import ResultDecoder
 from .runtime_job import RuntimeJob
 from .runtime_program import RuntimeProgram, ParameterNamespace
-from .runtime_session import RuntimeSession  # pylint: disable=cyclic-import
 from .utils import RuntimeDecoder, to_base64_string, to_python_identifier
-from .utils.backend_decoder import configuration_from_server_data
-from .utils.hgp import to_instance_format, from_instance_format
 from .api.client_parameters import ClientParameters
 from .runtime_options import RuntimeOptions
-from .utils.deprecation import (
-    deprecate_function,
-    deprecate_arguments,
-)
+from .ibm_backend import IBMBackend
 
 logger = logging.getLogger(__name__)
 
 SERVICE_NAME = "runtime"
 
-DEPRECATED_PROGRAMS = [
-    "torch-train",
-    "torch-infer",
-    "sample-expval",
-    "quantum_kernal_alignment",
-    "sample-program",
-]
-
 
 class QiskitRuntimeService(Provider):
     """Class for interacting with the Qiskit Runtime service.
@@ -106,9 +99,6 @@ class QiskitRuntimeService(Provider):
                 circuits=[psi], observables=[H1], parameter_values=[theta]
             )
             print(f"Estimator results: {job.result()}")
-            # Close the session only if all jobs are finished
-            # and you don't need to run more in the session.
-            session.close()
 
     The example above uses the dedicated :class:`~qiskit_ibm_runtime.Sampler`
     and :class:`~qiskit_ibm_runtime.Estimator` classes. You can also
@@ -125,10 +115,11 @@ class QiskitRuntimeService(Provider):
     canceling job.
     """
 
+    global_service = None
+
     def __init__(
         self,
         channel: Optional[ChannelType] = None,
-        auth: Optional[AccountType] = None,
         token: Optional[str] = None,
         url: Optional[str] = None,
         filename: Optional[str] = None,
@@ -136,6 +127,7 @@ class QiskitRuntimeService(Provider):
         instance: Optional[str] = None,
         proxies: Optional[dict] = None,
         verify: Optional[bool] = None,
+        channel_strategy: Optional[str] = None,
     ) -> None:
         """QiskitRuntimeService constructor
 
@@ -144,6 +136,7 @@ class QiskitRuntimeService(Provider):
             - Account with the input `name`, if specified.
             - Default account for the `channel` type, if `channel` is specified but `token` is not.
             - Account defined by the input `channel` and `token`, if specified.
+            - Account defined by the `default_channel` if defined in filename
             - Account defined by the environment variables, if defined.
             - Default account for the ``ibm_cloud`` account, if one is available.
             - Default account for the ``ibm_quantum`` account, if one is available.
@@ -153,7 +146,6 @@ class QiskitRuntimeService(Provider):
 
         Args:
             channel: Channel type. ``ibm_cloud`` or ``ibm_quantum``.
-            auth: (DEPRECATED, use `channel` instead) Authentication type. ``cloud`` or ``legacy``.
             token: IBM Cloud API key or IBM Quantum API token.
             url: The API URL.
                 Defaults to https://cloud.ibm.com (ibm_cloud) or
@@ -170,6 +162,7 @@ class QiskitRuntimeService(Provider):
                 ``username_ntlm``, ``password_ntlm`` (username and password to enable NTLM user
                 authentication)
             verify: Whether to verify the server's TLS certificate.
+            channel_strategy: Error mitigation strategy.
 
         Returns:
             An instance of QiskitRuntimeService.
@@ -179,19 +172,16 @@ class QiskitRuntimeService(Provider):
         """
         super().__init__()
 
-        if auth:
-            self._auth_warning()
-
         self._account = self._discover_account(
             token=token,
             url=url,
             instance=instance,
             channel=channel,
-            auth=auth,
             filename=filename,
             name=name,
             proxies=ProxyConfiguration(**proxies) if proxies else None,
             verify=verify,
+            channel_strategy=channel_strategy,
         )
 
         self._client_params = ClientParameters(
@@ -203,105 +193,103 @@ class QiskitRuntimeService(Provider):
             verify=self._account.verify,
         )
 
+        self._channel_strategy = channel_strategy or self._account.channel_strategy
         self._channel = self._account.channel
         self._programs: Dict[str, RuntimeProgram] = {}
         self._backends: Dict[str, "ibm_backend.IBMBackend"] = {}
+        self._backend_configs: Dict[str, Any] = {}
 
         if self._channel == "ibm_cloud":
             self._api_client = RuntimeClient(self._client_params)
             # TODO: We can make the backend discovery lazy
             self._backends = self._discover_cloud_backends()
+            QiskitRuntimeService.global_service = self
             return
         else:
             auth_client = self._authenticate_ibm_quantum_account(self._client_params)
             # Update client parameters to use authenticated values.
-            self._client_params.url = auth_client.current_service_urls()["services"][
-                "runtime"
-            ]
+            self._client_params.url = auth_client.current_service_urls()["services"]["runtime"]
             self._client_params.token = auth_client.current_access_token()
             self._api_client = RuntimeClient(self._client_params)
             self._hgps = self._initialize_hgps(auth_client)
             for hgp in self._hgps.values():
-                for backend_name, backend in hgp.backends.items():
+                for backend_name in hgp.backends:
                     if backend_name not in self._backends:
-                        self._backends[backend_name] = backend
+                        self._backends[backend_name] = None
+            self._current_instance = self._account.instance
+            if not self._current_instance:
+                self._current_instance = self._get_hgp().name
+                logger.info("Default instance: %s", self._current_instance)
+        QiskitRuntimeService.global_service = self
 
         # TODO - it'd be nice to allow some kind of autocomplete, but `service.ibmq_foo`
         # just seems wrong since backends are not runtime service instances.
         # self._discover_backends()
 
-    @staticmethod
-    def _auth_warning() -> None:
-        warnings.warn(
-            "Use of `auth` parameter is deprecated and will "
-            "be removed in a future release. "
-            "You can now use channel='ibm_cloud' or "
-            "channel='ibm_quantum' instead.",
-            DeprecationWarning,
-            stacklevel=3,
-        )
-
     def _discover_account(
         self,
         token: Optional[str] = None,
         url: Optional[str] = None,
         instance: Optional[str] = None,
         channel: Optional[ChannelType] = None,
-        auth: Optional[AccountType] = None,
         filename: Optional[str] = None,
         name: Optional[str] = None,
         proxies: Optional[ProxyConfiguration] = None,
         verify: Optional[bool] = None,
+        channel_strategy: Optional[str] = None,
     ) -> Account:
         """Discover account."""
         account = None
         verify_ = verify or True
+        if channel_strategy:
+            if channel_strategy not in ["q-ctrl", "default"]:
+                raise ValueError(f"{channel_strategy} is not a valid channel strategy.")
+            if channel and channel != "ibm_cloud":
+                raise ValueError(
+                    f"The channel strategy {channel_strategy} is "
+                    "only supported on the ibm_cloud channel."
+                )
         if name:
             if filename:
-                if any([auth, channel, token, url]):
+                if any([channel, token, url]):
                     logger.warning(
-                        "Loading account from file %s with name %s. Any input 'auth', "
+                        "Loading account from file %s with name %s. Any input "
                         "'channel', 'token' or 'url' are ignored.",
                         filename,
                         name,
                     )
             else:
-                if any([auth, channel, token, url]):
+                if any([channel, token, url]):
                     logger.warning(
-                        "Loading account with name %s. Any input 'auth', "
+                        "Loading account with name %s. Any input "
                         "'channel', 'token' or 'url' are ignored.",
                         name,
                     )
             account = AccountManager.get(filename=filename, name=name)
-        elif auth or channel:
-            if auth and auth not in ["legacy", "cloud"]:
-                raise ValueError("'auth' can only be 'cloud' or 'legacy'")
+        elif channel:
             if channel and channel not in ["ibm_cloud", "ibm_quantum"]:
                 raise ValueError("'channel' can only be 'ibm_cloud' or 'ibm_quantum'")
-            channel = channel or self._get_channel_for_auth(auth=auth)
             if token:
-                account = Account(
+                account = Account.create_account(
                     channel=channel,
                     token=token,
                     url=url,
                     instance=instance,
                     proxies=proxies,
                     verify=verify_,
+                    channel_strategy=channel_strategy,
                 )
             else:
                 if url:
-                    logger.warning(
-                        "Loading default %s account. Input 'url' is ignored.", channel
-                    )
-                account = AccountManager.get(
-                    filename=filename, name=name, channel=channel
-                )
+                    logger.warning("Loading default %s account. Input 'url' is ignored.", channel)
+                account = AccountManager.get(filename=filename, name=name, channel=channel)
         elif any([token, url]):
             # Let's not infer based on these attributes as they may change in the future.
             raise ValueError(
-                "'channel' or 'auth' is required if 'token', or 'url' is specified but 'name' is not."
+                "'channel' is required if 'token', or 'url' is specified but 'name' is not."
             )
 
+        # channel is not defined yet, get it from the AccountManager
         if account is None:
             account = AccountManager.get(filename=filename)
 
@@ -313,8 +301,7 @@ class QiskitRuntimeService(Provider):
             account.verify = verify
 
         # resolve CRN if needed
-        if account.channel == "ibm_cloud":
-            self._resolve_crn(account)
+        self._resolve_crn(account)
 
         # ensure account is valid, fail early if not
         account.validate()
@@ -328,11 +315,9 @@ class QiskitRuntimeService(Provider):
             A dict of the remote backend instances, keyed by backend name.
         """
         ret = OrderedDict()  # type: ignore[var-annotated]
-        backends_list = self._api_client.list_backends()
+        backends_list = self._api_client.list_backends(channel_strategy=self._channel_strategy)
         for backend_name in backends_list:
-            raw_config = self._api_client.backend_configuration(
-                backend_name=backend_name
-            )
+            raw_config = self._api_client.backend_configuration(backend_name=backend_name)
             config = configuration_from_server_data(
                 raw_config=raw_config, instance=self._account.instance
             )
@@ -348,9 +333,7 @@ class QiskitRuntimeService(Provider):
     def _resolve_crn(self, account: Account) -> None:
         account.resolve_crn()
 
-    def _authenticate_ibm_quantum_account(
-        self, client_params: ClientParameters
-    ) -> AuthClient:
+    def _authenticate_ibm_quantum_account(self, client_params: ClientParameters) -> AuthClient:
         """Authenticate against IBM Quantum and populate the hub/group/projects.
 
         Args:
@@ -392,6 +375,7 @@ class QiskitRuntimeService(Provider):
         Raises:
             IBMInputValueError: If the URL specified is not a valid IBM Quantum authentication URL.
             IBMAccountError: If no hub/group/project could be found for this account.
+            IBMInputValueError: If instance parameter is not found in hgps.
 
         Returns:
             The hub/group/projects for this account.
@@ -442,9 +426,8 @@ class QiskitRuntimeService(Provider):
                 # Move user selected hgp to front of the list
                 hgps.move_to_end(default_hgp, last=False)
             else:
-                warnings.warn(
-                    f"Default hub/group/project {default_hgp} not "
-                    "found for the account and is ignored."
+                raise IBMInputValueError(
+                    f"Hub/group/project {default_hgp} could not be found for this account."
                 )
         return hgps
 
@@ -487,13 +470,11 @@ class QiskitRuntimeService(Provider):
             _ = from_instance_format(instance)  # Verify format
             if instance not in self._hgps:
                 raise IBMInputValueError(
-                    f"Hub/group/project {instance} "
-                    "could not be found for this account."
+                    f"Hub/group/project {instance} " "could not be found for this account."
                 )
-            if backend_name and not self._hgps[instance].backend(backend_name):
+            if backend_name and not self._hgps[instance].has_backend(backend_name):
                 raise QiskitBackendNotFoundError(
-                    f"Backend {backend_name} cannot be found in "
-                    f"hub/group/project {instance}"
+                    f"Backend {backend_name} cannot be found in " f"hub/group/project {instance}"
                 )
             return self._hgps[instance]
 
@@ -501,12 +482,11 @@ class QiskitRuntimeService(Provider):
             return list(self._hgps.values())[0]
 
         for hgp in self._hgps.values():
-            if hgp.backend(backend_name):
+            if hgp.has_backend(backend_name):
                 return hgp
 
         error_message = (
-            f"Backend {backend_name} cannot be found in any "
-            f"hub/group/project for this account."
+            f"Backend {backend_name} cannot be found in any " f"hub/group/project for this account."
         )
         if not isinstance(backend_name, str):
             error_message += (
@@ -570,13 +550,46 @@ class QiskitRuntimeService(Provider):
 
         Raises:
             IBMInputValueError: If an input is invalid.
+            QiskitBackendNotFoundError: If the backend is not in any instance.
         """
         # TODO filter out input_allowed not having runtime
+        backends: List[IBMBackend] = []
+        instance_filter = instance if instance else self._account.instance
         if self._channel == "ibm_quantum":
-            if instance:
-                backends = list(self._get_hgp(instance=instance).backends.values())
+            if name:
+                if name not in self._backends:
+                    raise QiskitBackendNotFoundError("No backend matches the criteria.")
+                if not self._backends[name] or instance != self._backends[name]._instance:
+                    self._set_backend_config(name)
+                    self._backends[name] = self._create_backend_obj(
+                        self._backend_configs[name],
+                        instance,
+                    )
+                if self._backends[name]:
+                    backends.append(self._backends[name])
+            elif instance_filter:
+                hgp = self._get_hgp(instance=instance_filter)
+                for backend_name in hgp.backends:
+                    if (
+                        not self._backends[backend_name]
+                        or instance_filter != self._backends[backend_name]._instance
+                    ):
+                        self._set_backend_config(backend_name, instance_filter)
+                        self._backends[backend_name] = self._create_backend_obj(
+                            self._backend_configs[backend_name], instance_filter
+                        )
+                    if self._backends[backend_name]:
+                        backends.append(self._backends[backend_name])
             else:
-                backends = list(self._backends.values())
+                for backend_name, backend_config in self._backends.items():
+                    if not backend_config:
+                        self._set_backend_config(backend_name)
+                        self._backends[backend_name] = self._create_backend_obj(
+                            self._backend_configs[backend_name]
+                        )
+                    if self._backends[backend_name]:
+                        backends.append(self._backends[backend_name])
+
         else:
             if instance:
                 raise IBMInputValueError(
@@ -592,6 +605,52 @@ class QiskitRuntimeService(Provider):
             )
         return filter_backends(backends, filters=filters, **kwargs)
 
+    def _set_backend_config(self, backend_name: str, instance: Optional[str] = None) -> None:
+        """Retrieve backend configuration and add to backend_configs.
+        Args:
+            backend_name: backend name that will be returned.
+            instance: the current h/g/p.
+        """
+        if backend_name not in self._backend_configs:
+            raw_config = self._api_client.backend_configuration(backend_name)
+            config = configuration_from_server_data(raw_config=raw_config, instance=instance)
+            self._backend_configs[backend_name] = config
+
+    def _create_backend_obj(
+        self,
+        config: Union[QasmBackendConfiguration, PulseBackendConfiguration],
+        instance: Optional[str] = None,
+    ) -> IBMBackend:
+        """Given a backend configuration return the backend object.
+        Args:
+            config: backend configuration.
+            instance: the current h/g/p.
+        Returns:
+            A backend object.
+        Raises:
+            QiskitBackendNotFoundError: if the backend is not in the hgp passed in.
+        """
+        if config:
+            if not instance:
+                for hgp in list(self._hgps.values()):
+                    if config.backend_name in hgp.backends:
+                        instance = to_instance_format(hgp._hub, hgp._group, hgp._project)
+                        break
+
+            elif config.backend_name not in self._get_hgp(instance=instance).backends:
+                raise QiskitBackendNotFoundError(
+                    f"Backend {config.backend_name} is not in "
+                    f"{instance}: please try a different hub/group/project."
+                )
+
+            return ibm_backend.IBMBackend(
+                instance=instance,
+                configuration=config,
+                service=self,
+                api_client=self._api_client,
+            )
+        return None
+
     def active_account(self) -> Optional[Dict[str, str]]:
         """Return the IBM Quantum account currently in use for the session.
 
@@ -604,7 +663,6 @@ class QiskitRuntimeService(Provider):
     def delete_account(
         filename: Optional[str] = None,
         name: Optional[str] = None,
-        auth: Optional[str] = None,
         channel: Optional[ChannelType] = None,
     ) -> bool:
         """Delete a saved account from disk.
@@ -612,8 +670,6 @@ class QiskitRuntimeService(Provider):
         Args:
             filename: Name of file from which to delete the account.
             name: Name of the saved account to delete.
-            auth: (DEPRECATED, use `channel` instead) Authentication type of the default
-                account to delete. Ignored if account name is provided.
             channel: Channel type of the default account to delete.
                 Ignored if account name is provided.
 
@@ -621,31 +677,21 @@ class QiskitRuntimeService(Provider):
             True if the account was deleted.
             False if no account was found.
         """
-        if auth:
-            QiskitRuntimeService._auth_warning()
-            channel = channel or QiskitRuntimeService._get_channel_for_auth(auth=auth)
-
         return AccountManager.delete(filename=filename, name=name, channel=channel)
 
-    @staticmethod
-    def _get_channel_for_auth(auth: str) -> str:
-        """Returns channel type based on auth"""
-        if auth == "legacy":
-            return "ibm_quantum"
-        return "ibm_cloud"
-
     @staticmethod
     def save_account(
         token: Optional[str] = None,
         url: Optional[str] = None,
         instance: Optional[str] = None,
         channel: Optional[ChannelType] = None,
-        auth: Optional[AccountType] = None,
         filename: Optional[str] = None,
         name: Optional[str] = None,
         proxies: Optional[dict] = None,
         verify: Optional[bool] = None,
         overwrite: Optional[bool] = False,
+        channel_strategy: Optional[str] = None,
+        set_as_default: Optional[bool] = None,
     ) -> None:
         """Save the account to disk for future use.
 
@@ -656,7 +702,6 @@ class QiskitRuntimeService(Provider):
                 https://auth.quantum-computing.ibm.com/api (ibm_quantum).
             instance: The CRN (ibm_cloud) or hub/group/project (ibm_quantum).
             channel: Channel type. `ibm_cloud` or `ibm_quantum`.
-            auth: (DEPRECATED, use `channel` instead) Authentication type. `cloud` or `legacy`.
             filename: Full path of the file where the account is saved.
             name: Name of the account to save.
             proxies: Proxy configuration. Supported optional keys are
@@ -666,10 +711,10 @@ class QiskitRuntimeService(Provider):
                 authentication)
             verify: Verify the server's TLS certificate.
             overwrite: ``True`` if the existing account is to be overwritten.
+            channel_strategy: Error mitigation strategy.
+            set_as_default: If ``True``, the account is saved in filename,
+                as the default account.
         """
-        if auth:
-            QiskitRuntimeService._auth_warning()
-            channel = channel or QiskitRuntimeService._get_channel_for_auth(auth)
 
         AccountManager.save(
             token=token,
@@ -681,12 +726,13 @@ class QiskitRuntimeService(Provider):
             proxies=ProxyConfiguration(**proxies) if proxies else None,
             verify=verify,
             overwrite=overwrite,
+            channel_strategy=channel_strategy,
+            set_as_default=set_as_default,
         )
 
     @staticmethod
     def saved_accounts(
         default: Optional[bool] = None,
-        auth: Optional[str] = None,
         channel: Optional[ChannelType] = None,
         filename: Optional[str] = None,
         name: Optional[str] = None,
@@ -695,8 +741,6 @@ class QiskitRuntimeService(Provider):
 
         Args:
             default: If set to True, only default accounts are returned.
-            auth: (DEPRECATED, use `channel` instead) If set, only accounts with the given
-                authentication type are returned.
             channel: Channel type. `ibm_cloud` or `ibm_quantum`.
             filename: Name of file whose accounts are returned.
             name: If set, only accounts with the given name are returned.
@@ -707,9 +751,6 @@ class QiskitRuntimeService(Provider):
         Raises:
             ValueError: If an invalid account is found on disk.
         """
-        if auth:
-            QiskitRuntimeService._auth_warning()
-            channel = channel or QiskitRuntimeService._get_channel_for_auth(auth)
         return dict(
             map(
                 lambda kv: (kv[0], Account.to_saved_format(kv[1])),
@@ -730,7 +771,7 @@ class QiskitRuntimeService(Provider):
             name: Name of the backend.
             instance: This is only supported for ``ibm_quantum`` runtime and is in the
                 hub/group/project format. If an instance is not given, among the providers
-                with access to the backend, a premium provider will be priotized.
+                with access to the backend, a premium provider will be prioritized.
                 For users without access to a premium provider, the default open provider will be used.
 
         Returns:
@@ -748,9 +789,7 @@ class QiskitRuntimeService(Provider):
                     " Learn more about available backends here "
                     "https://cloud.ibm.com/docs/quantum-computing?topic=quantum-computing-choose-backend "
                 )
-            raise QiskitBackendNotFoundError(
-                "No backend matches the criteria." + cloud_msg_url
-            )
+            raise QiskitBackendNotFoundError("No backend matches the criteria." + cloud_msg_url)
         return backends[0]
 
     def get_backend(self, name: str = None, **kwargs: Any) -> Backend:
@@ -808,9 +847,7 @@ class QiskitRuntimeService(Provider):
             current_page_limit = 20
             offset = 0
             while True:
-                response = self._api_client.list_programs(
-                    limit=current_page_limit, skip=offset
-                )
+                response = self._api_client.list_programs(limit=current_page_limit, skip=offset)
                 program_page = response.get("programs", [])
                 # count is the total number of programs that would be returned if
                 # there was no limit or skip
@@ -821,9 +858,7 @@ class QiskitRuntimeService(Provider):
                     program = self._to_program(prog_dict)
                     self._programs[program.program_id] = program
                 num_cached_programs = len(self._programs)
-                if num_cached_programs == count or num_cached_programs >= (
-                    limit + skip
-                ):
+                if num_cached_programs == count or num_cached_programs >= (limit + skip):
                     # Stop if there are no more programs returned by the server or
                     # if the number of cached programs is greater than the sum of limit and skip
                     break
@@ -854,9 +889,7 @@ class QiskitRuntimeService(Provider):
                 response = self._api_client.program_get(program_id)
             except RequestsApiError as ex:
                 if ex.status_code == 404:
-                    raise RuntimeProgramNotFound(
-                        f"Program not found: {ex.message}"
-                    ) from None
+                    raise RuntimeProgramNotFound(f"Program not found: {ex.message}") from None
                 raise IBMRuntimeError(f"Failed to get program: {ex}") from None
 
             self._programs[program_id] = self._to_program(response)
@@ -904,13 +937,8 @@ class QiskitRuntimeService(Provider):
         inputs: Union[Dict, ParameterNamespace],
         options: Optional[Union[RuntimeOptions, Dict]] = None,
         callback: Optional[Callable] = None,
-        result_decoder: Optional[
-            Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]
-        ] = None,
-        instance: Optional[str] = None,
+        result_decoder: Optional[Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]] = None,
         session_id: Optional[str] = None,
-        job_tags: Optional[List[str]] = None,
-        max_execution_time: Optional[int] = None,
         start_session: Optional[bool] = False,
     ) -> RuntimeJob:
         """Execute the runtime program.
@@ -932,13 +960,7 @@ class QiskitRuntimeService(Provider):
                 If more than one decoder is specified, the first is used for interim results and
                 the second final results. If not specified, a program-specific decoder or the default
                 ``ResultDecoder`` is used.
-            instance: (DEPRECATED) This is only supported for ``ibm_quantum`` runtime and is in the
-                hub/group/project format.
             session_id: Job ID of the first job in a runtime session.
-            job_tags: (DEPRECATED) Tags to be assigned to the job. The tags can subsequently be used
-                as a filter in the :meth:`jobs()` function call.
-            max_execution_time: (DEPRECATED) Maximum execution time in seconds. This overrides
-                the max_execution_time of the program.
             start_session: Set to True to explicitly start a runtime session. Defaults to False.
 
         Returns:
@@ -949,50 +971,33 @@ class QiskitRuntimeService(Provider):
             RuntimeProgramNotFound: If the program cannot be found.
             IBMRuntimeError: An error occurred running the program.
         """
-        if program_id in DEPRECATED_PROGRAMS:
-            warnings.warn(
-                f"The {program_id} program has been deprecated as of qiskit-ibm-runtime 0.7 \
-                and will be removed no sooner than 1 month after the release date.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         qrt_options: RuntimeOptions = options
         if options is None:
             qrt_options = RuntimeOptions()
         elif isinstance(options, Dict):
             qrt_options = RuntimeOptions(**options)
 
-        deprecated = {
-            "instance": instance,
-            "job_tags": job_tags,
-            "max_execution_time": max_execution_time,
-        }
-        for name, param in deprecated.items():
-            if param is not None:
-                deprecate_arguments(
-                    deprecated=name,
-                    version="0.7",
-                    remedy=f'Please specify "{name}" inside "options".',
-                )
-                setattr(qrt_options, name, param)
-
-        # If using params object, extract as dictionary
+        # If using params object, extract as dictionary.
         if isinstance(inputs, ParameterNamespace):
             inputs.validate()
             inputs = vars(inputs)
 
         qrt_options.validate(channel=self.channel)
 
-        backend = None
         hgp_name = None
         if self._channel == "ibm_quantum":
             # Find the right hgp
-            hgp = self._get_hgp(
-                instance=qrt_options.instance, backend_name=qrt_options.backend
-            )
-            backend = hgp.backend(qrt_options.backend)
+            hgp = self._get_hgp(instance=qrt_options.instance, backend_name=qrt_options.backend)
             hgp_name = hgp.name
+            if hgp_name != self._current_instance:
+                self._current_instance = hgp_name
+                logger.info("Instance selected: %s", self._current_instance)
+        backend = self.backend(name=qrt_options.backend, instance=hgp_name)
+        status = backend.status()
+        if status.operational is True and status.status_msg != "active":
+            warnings.warn(
+                f"The backend {backend.name} currently has a status of {status.status_msg}."
+            )
 
         try:
             response = self._api_client.program_run(
@@ -1007,16 +1012,25 @@ class QiskitRuntimeService(Provider):
                 max_execution_time=qrt_options.max_execution_time,
                 start_session=start_session,
                 session_time=qrt_options.session_time,
+                channel_strategy=None
+                if self._channel_strategy == "default"
+                else self._channel_strategy,
             )
+            if self._channel == "ibm_quantum":
+                messages = response.get("messages")
+                if messages:
+                    warning_message = messages[0].get("data")
+                    warnings.warn(warning_message)
+
         except RequestsApiError as ex:
             if ex.status_code == 404:
-                raise RuntimeProgramNotFound(
-                    f"Program not found: {ex.message}"
-                ) from None
+                raise RuntimeProgramNotFound(f"Program not found: {ex.message}") from None
             raise IBMRuntimeError(f"Failed to run program: {ex}") from None
-
-        if not backend:
-            backend = self.backend(name=response["backend"])
+        backend = (
+            self.backend(name=response["backend"], instance=hgp_name)
+            if response["backend"]
+            else qrt_options.backend
+        )
 
         job = RuntimeJob(
             backend=backend,
@@ -1024,7 +1038,6 @@ class QiskitRuntimeService(Provider):
             client_params=self._client_params,
             job_id=response["id"],
             program_id=program_id,
-            params=inputs,
             user_callback=callback,
             result_decoder=result_decoder,
             image=qrt_options.image,
@@ -1032,36 +1045,7 @@ class QiskitRuntimeService(Provider):
         )
         return job
 
-    @deprecate_function(
-        "QiskitRuntimeService.open",
-        "0.7",
-        "Instead, use the qiskit_ibm_runtime.Session class to create a runtime session.",
-    )
-    def open(
-        self,
-        program_id: str,
-        inputs: Union[Dict, ParameterNamespace],
-        options: Optional[Union[RuntimeOptions, Dict]] = None,
-    ) -> RuntimeSession:
-        """Open a new runtime session.
-
-        Args:
-            program_id: Program ID.
-            inputs: Initial program input parameters. These input values are
-                persistent throughout the session.
-            options: Runtime options that control the execution environment. See
-                :class:`RuntimeOptions` for all available options.
-
-        Returns:
-            Runtime session.
-        """
-        return RuntimeSession(
-            service=self, program_id=program_id, inputs=inputs, options=options
-        )
-
-    def upload_program(
-        self, data: str, metadata: Optional[Union[Dict, str]] = None
-    ) -> str:
+    def upload_program(self, data: str, metadata: Optional[Union[Dict, str]] = None) -> str:
         """Upload a runtime program.
 
         In addition to program data, the following program metadata is also
@@ -1131,9 +1115,7 @@ class QiskitRuntimeService(Provider):
                     "Program with the same name already exists."
                 ) from None
             if ex.status_code == 403:
-                raise IBMNotAuthorizedError(
-                    "You are not authorized to upload programs."
-                ) from None
+                raise IBMNotAuthorizedError("You are not authorized to upload programs.") from None
             raise IBMRuntimeError(f"Failed to create program: {ex}") from None
         return response["id"]
 
@@ -1220,14 +1202,10 @@ class QiskitRuntimeService(Provider):
         )
 
         try:
-            self._api_client.program_update(
-                program_id, program_data=data, **combined_metadata
-            )
+            self._api_client.program_update(program_id, program_data=data, **combined_metadata)
         except RequestsApiError as ex:
             if ex.status_code == 404:
-                raise RuntimeProgramNotFound(
-                    f"Program not found: {ex.message}"
-                ) from None
+                raise RuntimeProgramNotFound(f"Program not found: {ex.message}") from None
             raise IBMRuntimeError(f"Failed to update program: {ex}") from None
 
         if program_id in self._programs:
@@ -1266,9 +1244,7 @@ class QiskitRuntimeService(Provider):
             self._api_client.program_delete(program_id=program_id)
         except RequestsApiError as ex:
             if ex.status_code == 404:
-                raise RuntimeProgramNotFound(
-                    f"Program not found: {ex.message}"
-                ) from None
+                raise RuntimeProgramNotFound(f"Program not found: {ex.message}") from None
             raise IBMRuntimeError(f"Failed to delete program: {ex}") from None
 
         if program_id in self._programs:
@@ -1290,9 +1266,7 @@ class QiskitRuntimeService(Provider):
             self._api_client.set_program_visibility(program_id, public)
         except RequestsApiError as ex:
             if ex.status_code == 404:
-                raise RuntimeProgramNotFound(
-                    f"Program not found: {ex.message}"
-                ) from None
+                raise RuntimeProgramNotFound(f"Program not found: {ex.message}") from None
             raise IBMRuntimeError(f"Failed to set program visibility: {ex}") from None
 
         if program_id in self._programs:
@@ -1313,7 +1287,7 @@ class QiskitRuntimeService(Provider):
             IBMRuntimeError: If the request failed.
         """
         try:
-            response = self._api_client.job_get(job_id)
+            response = self._api_client.job_get(job_id, exclude_params=True)
         except RequestsApiError as ex:
             if ex.status_code == 404:
                 raise RuntimeJobNotFound(f"Job not found: {ex.message}") from None
@@ -1521,15 +1495,15 @@ class QiskitRuntimeService(Provider):
             raise QiskitBackendNotFoundError("No backend matches the criteria.")
         return min(candidates, key=lambda b: b.status().pending_jobs)
 
-    @property
-    def auth(self) -> str:
-        """Return the authentication type used.
+    def instances(self) -> List[str]:
+        """Return the IBM Quantum instances list currently in use for the session.
 
         Returns:
-            The authentication type used.
+            A list with instances currently in the session.
         """
-        self._auth_warning()
-        return "cloud" if self._channel == "ibm_cloud" else "legacy"
+        if self._channel == "ibm_quantum":
+            return list(self._hgps.keys())
+        return []
 
     @property
     def channel(self) -> str:
