@@ -27,10 +27,12 @@ from qiskit.providers.jobstatus import JobStatus, JOB_FINAL_STATES
 from qiskit.providers.job import JobV1 as Job
 
 # pylint: disable=unused-import,cyclic-import
+from qiskit_ibm_provider.utils import validate_job_tags, utc_to_local
 from qiskit_ibm_runtime import qiskit_runtime_service
 
 from .constants import API_TO_JOB_ERROR_MESSAGE, API_TO_JOB_STATUS, DEFAULT_DECODERS
 from .exceptions import (
+    IBMApiError,
     RuntimeJobFailureError,
     RuntimeInvalidStateError,
     IBMRuntimeError,
@@ -38,10 +40,10 @@ from .exceptions import (
     RuntimeJobMaxTimeoutError,
 )
 from .program.result_decoder import ResultDecoder
+from .utils import RuntimeDecoder
 from .api.clients import RuntimeClient, RuntimeWebsocketClient, WebsocketClientCloseCode
 from .exceptions import IBMError
 from .api.exceptions import RequestsApiError
-from .utils.converters import utc_to_local
 from .api.client_parameters import ClientParameters
 from .utils.utils import CallableStr
 
@@ -97,9 +99,7 @@ class RuntimeJob(Job):
         params: Optional[Dict] = None,
         creation_date: Optional[str] = None,
         user_callback: Optional[Callable] = None,
-        result_decoder: Optional[
-            Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]
-        ] = None,
+        result_decoder: Optional[Union[Type[ResultDecoder], Sequence[Type[ResultDecoder]]]] = None,
         image: Optional[str] = "",
         session_id: Optional[str] = None,
         tags: Optional[List] = None,
@@ -136,10 +136,9 @@ class RuntimeJob(Job):
         self._service = service
         self._session_id = session_id
         self._tags = tags
+        self._usage_estimation: Dict[str, Any] = {}
 
-        decoder = (
-            result_decoder or DEFAULT_DECODERS.get(program_id, None) or ResultDecoder
-        )
+        decoder = result_decoder or DEFAULT_DECODERS.get(program_id, None) or ResultDecoder
         if isinstance(decoder, Sequence):
             self._interim_result_decoder, self._final_result_decoder = decoder
         else:
@@ -149,9 +148,7 @@ class RuntimeJob(Job):
         self._ws_client_future = None  # type: Optional[futures.Future]
         self._result_queue = queue.Queue()  # type: queue.Queue
         self._ws_client = RuntimeWebsocketClient(
-            websocket_url=client_params.get_runtime_api_base_url().replace(
-                "https", "wss"
-            ),
+            websocket_url=client_params.get_runtime_api_base_url().replace("https", "wss"),
             client_params=client_params,
             job_id=job_id,
             message_queue=self._result_queue,
@@ -166,14 +163,15 @@ class RuntimeJob(Job):
         Args:
             response: Response to check for url keyword, if available, download result from given URL
         """
-        if "url" in response:
+        try:
             result_url_json = json.loads(response)
             if "url" in result_url_json:
                 url = result_url_json["url"]
-                result_response = requests.get(url)
-                response = result_response.content
-
-        return response
+                result_response = requests.get(url, timeout=10)
+                return result_response.content
+            return response
+        except json.JSONDecodeError:
+            return response
 
     def interim_results(self, decoder: Optional[Type[ResultDecoder]] = None) -> Any:
         """Return the interim results of the job.
@@ -189,9 +187,7 @@ class RuntimeJob(Job):
         """
         if not self._final_interim_results:
             _decoder = decoder or self._interim_result_decoder
-            interim_results_raw = self._api_client.job_interim_results(
-                job_id=self.job_id()
-            )
+            interim_results_raw = self._api_client.job_interim_results(job_id=self.job_id())
             self._interim_results = _decoder.decode(interim_results_raw)
             if self.status() in JOB_FINAL_STATES:
                 self._final_interim_results = True
@@ -214,16 +210,20 @@ class RuntimeJob(Job):
         Raises:
             RuntimeJobFailureError: If the job failed.
             RuntimeJobMaxTimeoutError: If the job does not complete within given timeout.
+            RuntimeInvalidStateError: If the job was cancelled, and attempting to retrieve result.
         """
         _decoder = decoder or self._final_result_decoder
         if self._results is None or (_decoder != self._final_result_decoder):
             self.wait_for_final_state(timeout=timeout)
             if self._status == JobStatus.ERROR:
-                error_message = self.error_message()
+                error_message = self._reason if self._reason else self._error_message
                 if self._reason == "RAN TOO LONG":
                     raise RuntimeJobMaxTimeoutError(error_message)
-                raise RuntimeJobFailureError(
-                    f"Unable to retrieve job result. " f"{error_message}"
+                raise RuntimeJobFailureError(f"Unable to retrieve job result. {error_message}")
+            if self._status is JobStatus.CANCELLED:
+                raise RuntimeInvalidStateError(
+                    "Unable to retrieve result for job {}. "
+                    "Job was cancelled.".format(self.job_id())
                 )
 
             result_raw = self._download_external_result(
@@ -244,20 +244,19 @@ class RuntimeJob(Job):
             self._api_client.job_cancel(self.job_id())
         except RequestsApiError as ex:
             if ex.status_code == 409:
-                raise RuntimeInvalidStateError(
-                    f"Job cannot be cancelled: {ex}"
-                ) from None
+                raise RuntimeInvalidStateError(f"Job cannot be cancelled: {ex}") from None
             raise IBMRuntimeError(f"Failed to cancel job: {ex}") from None
         self.cancel_result_streaming()
         self._status = JobStatus.CANCELLED
 
-    def backend(self) -> Optional[Backend]:
+    def backend(self, timeout: Optional[float] = None) -> Optional[Backend]:
         """Return the backend where this job was executed. Retrieve data again if backend is None.
 
         Raises:
             IBMRuntimeError: If a network error occurred.
         """
         if not self._backend:  # type: ignore
+            self.wait_for_final_state(timeout=timeout)
             try:
                 raw_data = self._api_client.job_get(self.job_id())
                 if raw_data.get("backend"):
@@ -302,9 +301,7 @@ class RuntimeJob(Job):
         try:
             start_time = time.time()
             if self._status not in JOB_FINAL_STATES and not self._is_streaming():
-                self._ws_client_future = self._executor.submit(
-                    self._start_websocket_client
-                )
+                self._ws_client_future = self._executor.submit(self._start_websocket_client)
             if self._is_streaming():
                 self._ws_client_future.result(timeout)
             # poll for status after stream has closed until status is final
@@ -344,9 +341,7 @@ class RuntimeJob(Job):
         if self._status in JOB_FINAL_STATES:
             raise RuntimeInvalidStateError("Job already finished.")
         if self._is_streaming():
-            raise RuntimeInvalidStateError(
-                "A callback function is already streaming results."
-            )
+            raise RuntimeInvalidStateError("A callback function is already streaming results.")
         self._ws_client_future = self._executor.submit(self._start_websocket_client)
         self._executor.submit(
             self._stream_results,
@@ -392,8 +387,7 @@ class RuntimeJob(Job):
             IBMRuntimeError: If a network error occurred.
         """
         try:
-            metadata_str = self._api_client.job_metadata(self.job_id())
-            return json.loads(metadata_str)
+            return self._api_client.job_metadata(self.job_id())
         except RequestsApiError as err:
             raise IBMRuntimeError(f"Failed to get job metadata: {err}") from None
 
@@ -411,6 +405,35 @@ class RuntimeJob(Job):
             "QiskitRuntimeService.run() to submit a job."
         )
 
+    def update_tags(self, new_tags: List[str]) -> List[str]:
+        """Update the tags associated with this job.
+
+        Args:
+            new_tags: New tags to assign to the job.
+
+        Returns:
+            The new tags associated with this job.
+
+        Raises:
+            IBMApiError: If an unexpected error occurred when communicating
+                with the server or updating the job tags.
+        """
+        tags_to_update = set(new_tags)
+        validate_job_tags(new_tags, RuntimeInvalidStateError)
+
+        response = self._api_client.update_tags(job_id=self.job_id(), tags=list(tags_to_update))
+
+        if response.status_code == 204:
+            api_response = self._api_client.job_get(self.job_id())
+            self._tags = api_response.pop("tags", [])
+            return self._tags
+        else:
+            raise IBMApiError(
+                "An unexpected error occurred when updating the "
+                "tags for job {}. The tags were not updated for "
+                "the job.".format(self.job_id())
+            )
+
     def _set_status_and_error_message(self) -> None:
         """Fetch and set status and error message."""
         if self._status not in JOB_FINAL_STATES:
@@ -429,8 +452,15 @@ class RuntimeJob(Job):
         """
         try:
             reason = job_response["state"].get("reason")
+            reason_code = job_response["state"].get("reason_code")
             if reason:
-                self._reason = job_response["state"]["reason"].upper()
+                # TODO remove this in https://github.com/Qiskit/qiskit-ibm-runtime/issues/989
+                if reason.upper() == "RAN TOO LONG":
+                    self._reason = reason.upper()
+                else:
+                    self._reason = reason
+                if reason_code:
+                    self._reason = f"Error code {reason_code}; {self._reason}"
             self._status = self._status_from_job_response(job_response)
         except KeyError:
             raise IBMError(f"Unknown status: {job_response['state']['status']}")
@@ -456,6 +486,7 @@ class RuntimeJob(Job):
             Error message.
         """
         status = response["state"]["status"].upper()
+
         job_result_raw = self._download_external_result(
             self._api_client.job_results(job_id=self.job_id())
         )
@@ -463,10 +494,12 @@ class RuntimeJob(Job):
         if index != -1:
             job_result_raw = job_result_raw[index:]
 
-        error_msg = API_TO_JOB_ERROR_MESSAGE["FAILED"]
         if status == "CANCELLED" and self._reason == "RAN TOO LONG":
             error_msg = API_TO_JOB_ERROR_MESSAGE["CANCELLED - RAN TOO LONG"]
-        return error_msg.format(self.job_id(), job_result_raw)
+            return error_msg.format(self.job_id(), job_result_raw)
+        else:
+            error_msg = API_TO_JOB_ERROR_MESSAGE["FAILED"]
+            return error_msg.format(self.job_id(), self._reason or job_result_raw)
 
     def _status_from_job_response(self, response: Dict) -> str:
         """Returns the job status from an API response.
@@ -503,8 +536,7 @@ class RuntimeJob(Job):
             self._ws_client.job_results()
         except Exception:  # pylint: disable=broad-except
             logger.warning(
-                "An error occurred while streaming results "
-                "from the server for job %s:\n%s",
+                "An error occurred while streaming results from the server for job %s:\n%s",
                 self.job_id(),
                 traceback.format_exc(),
             )
@@ -538,7 +570,7 @@ class RuntimeJob(Job):
                 user_callback(self.job_id(), _decoder.decode(response))
             except Exception:  # pylint: disable=broad-except
                 logger.warning(
-                    "An error occurred while streaming results " "for job %s:\n%s",
+                    "An error occurred while streaming results for job %s:\n%s",
                     self.job_id(),
                     traceback.format_exc(),
                 )
@@ -626,3 +658,20 @@ class RuntimeJob(Job):
             Tags assigned to the job that can be used for filtering.
         """
         return self._tags
+
+    @property
+    def usage_estimation(self) -> Dict[str, Any]:
+        """Return the usage estimation infromation for this job.
+
+        Returns:
+            ``quantum_seconds`` which is the estimated system execution time
+            of the job in seconds. Quantum time represents the time that
+            the system is dedicated to processing your job.
+        """
+        if not self._usage_estimation:
+            response = self._api_client.job_get(job_id=self.job_id())
+            self._usage_estimation = {
+                "quantum_seconds": response.pop("estimated_running_time_seconds", None),
+            }
+
+        return self._usage_estimation
