@@ -12,21 +12,18 @@
 
 """Qiskit Runtime flexible session."""
 
-from typing import Dict, Optional, Type, Union, Callable
+from typing import Dict, Optional, Type, Union, Callable, Any
 from types import TracebackType
 from functools import wraps
 from contextvars import ContextVar
 
-from qiskit.circuit import QuantumCircuit
+from qiskit_ibm_provider.utils.converters import hms_to_seconds
 
 from qiskit_ibm_runtime import QiskitRuntimeService
 from .runtime_job import RuntimeJob
 from .runtime_program import ParameterNamespace
 from .program.result_decoder import ResultDecoder
 from .ibm_backend import IBMBackend
-from .utils.converters import hms_to_seconds
-from .utils.deprecation import issue_deprecation_msg
-from .exceptions import IBMInputValueError
 
 
 def _active_session(func):  # type: ignore
@@ -62,12 +59,10 @@ class Session:
 
         with Session(backend="ibmq_qasm_simulator") as session:
             sampler = Sampler(session=session, options=options)
-            job = sampler.run(circ)
+            job = sampler.run(ReferenceCircuits.bell())
             print(f"Sampler job ID: {job.job_id()}")
-            print(f"Sampler job result:" {job.result()})
-            # Close the session only if all jobs are finished and
-            # you don't need to run more in the session.
-            session.close()
+            print(f"Sampler job result: {job.result()}")
+
     """
 
     def __init__(
@@ -90,7 +85,7 @@ class Session:
             max_time: (EXPERIMENTAL setting, can break between releases without warning)
                 Maximum amount of time, a runtime session can be open before being
                 forcibly closed. Can be specified as seconds (int) or a string like "2h 30m 40s".
-                This value must be in between 300 seconds and the
+                This value must be less than the
                 `system imposed maximum
                 <https://qiskit.org/documentation/partners/qiskit_ibm_runtime/faqs/max_execution_time.html>`_.
 
@@ -99,11 +94,15 @@ class Session:
         """
 
         if service is None:
-            self._service = (
-                backend.service
-                if isinstance(backend, IBMBackend)
-                else QiskitRuntimeService()
-            )
+            if isinstance(backend, IBMBackend):
+                self._service = backend.service
+            else:
+                self._service = (
+                    QiskitRuntimeService()
+                    if QiskitRuntimeService.global_service is None
+                    else QiskitRuntimeService.global_service
+                )
+
         else:
             self._service = service
 
@@ -118,9 +117,6 @@ class Session:
 
         self._session_id: Optional[str] = None
         self._active = True
-
-        self._circuits_map: Dict[str, QuantumCircuit] = {}
-
         self._max_time = (
             max_time
             if max_time is None or isinstance(max_time, int)
@@ -143,36 +139,19 @@ class Session:
             inputs: Program input parameters. These input values are passed
                 to the runtime program.
             options: Runtime options that control the execution environment.
-                See :class:`qiskit_ibm_runtime.RuntimeOptions` for all available options,
-                EXCEPT ``backend``, which should be specified during session initialization.
+                See :class:`qiskit_ibm_runtime.RuntimeOptions` for all available options.
             callback: Callback function to be invoked for any interim results and final result.
 
         Returns:
             Submitted job.
-
-        Raises:
-            IBMInputValueError: If a backend is passed in through options that does not match
-                the current session backend.
         """
 
         options = options or {}
 
         if "instance" not in options:
             options["instance"] = self._instance
-        if "backend" in options:
-            issue_deprecation_msg(
-                "'backend' is no longer a supported option within a session",
-                "0.9",
-                "Instead, specify a backend when creating a Session instance.",
-                3,
-            )
-            if self._backend and options["backend"] != self._backend:
-                raise IBMInputValueError(
-                    f"The backend '{options['backend']}' is different from",
-                    f"the session backend '{self._backend}'",
-                )
-        else:
-            options["backend"] = self._backend
+
+        options["backend"] = self._backend
 
         if not self._session_id:
             # TODO: What happens if session max time != first job max time?
@@ -197,8 +176,16 @@ class Session:
 
         return job
 
+    def cancel(self) -> None:
+        """Cancel all pending jobs in a session."""
+        self._active = False
+        if self._session_id:
+            self._service._api_client.cancel_session(self._session_id)
+
     def close(self) -> None:
-        """Close the session."""
+        """Close the session so new jobs will no longer be accepted, but existing
+        queued or running jobs will run to completion. The session will be terminated once there
+        are no more pending jobs."""
         self._active = False
         if self._session_id:
             self._service._api_client.close_session(self._session_id)
@@ -211,6 +198,68 @@ class Session:
         """
         return self._backend
 
+    def status(self) -> Optional[str]:
+        """Return current session status.
+
+        Returns:
+            The current status of the session, including:
+            Pending: Session is created but not active.
+            It will become active when the next job of this session is dequeued.
+            In progress, accepting new jobs: session is active and accepting new jobs.
+            In progress, not accepting new jobs: session is active and not accepting new jobs.
+            Closed: max_time expired or session was explicitly closed.
+            None: status details are not available.
+        """
+        details = self.details()
+        if details:
+            state = details["state"]
+            accepting_jobs = details["accepting_jobs"]
+            if state in ["open", "inactive"]:
+                return "Pending"
+            if state == "active" and accepting_jobs:
+                return "In progress, accepting new jobs"
+            if state == "active" and not accepting_jobs:
+                return "In progress, not accepting new jobs"
+            return state.capitalize()
+
+        return None
+
+    def details(self) -> Optional[Dict[str, Any]]:
+        """Return session details.
+
+        Returns:
+            A dictionary with the sessions details, including:
+            id: id of the session.
+            backend_name: backend used for the session.
+            interactive_timeout: The maximum idle time (in seconds) between jobs that
+            is allowed to occur before the session is deactivated.
+            max_time: Maximum allowed time (in seconds) for the session, subject to plan limits.
+            active_timeout: The maximum time (in seconds) a session can stay active.
+            state: State of the session - open, active, inactive, or closed.
+            accepting_jobs: Whether or not the session is accepting jobs.
+            last_job_started: Timestamp of when the last job in the session started.
+            last_job_completed: Timestamp of when the last job in the session completed.
+            started_at: Timestamp of when the session was started.
+            closed_at: Timestamp of when the session was closed.
+        """
+        if self._session_id:
+            response = self._service._api_client.session_details(self._session_id)
+            if response:
+                return {
+                    "id": response.get("id"),
+                    "backend_name": response.get("backend_name"),
+                    "interactive_timeout": response.get("interactive_ttl"),
+                    "max_time": response.get("max_ttl"),
+                    "active_timeout": response.get("active_ttl"),
+                    "state": response.get("state"),
+                    "accepting_jobs": response.get("accepting_jobs"),
+                    "last_job_started": response.get("last_job_started"),
+                    "last_job_completed": response.get("last_job_completed"),
+                    "started_at": response.get("started_at"),
+                    "closed_at": response.get("closed_at"),
+                }
+        return None
+
     @property
     def session_id(self) -> str:
         """Return the session ID.
@@ -229,6 +278,30 @@ class Session:
         """
         return self._service
 
+    @classmethod
+    def from_id(
+        cls,
+        session_id: str,
+        service: Optional[QiskitRuntimeService] = None,
+        backend: Optional[Union[str, IBMBackend]] = None,
+    ) -> "Session":
+        """Construct a Session object with a given session_id
+
+        Args:
+            session_id: the id of the session to be created. This can be an already
+                existing session id.
+            service: instance of the ``QiskitRuntimeService`` class.
+            backend: instance of :class:`qiskit_ibm_runtime.IBMBackend` class or
+                string name of backend.
+
+        Returns:
+            A new Session with the given ``session_id``
+
+        """
+        session = cls(service, backend)
+        session._session_id = session_id
+        return session
+
     def __enter__(self) -> "Session":
         set_cm_session(self)
         return self
@@ -240,12 +313,11 @@ class Session:
         exc_tb: Optional[TracebackType],
     ) -> None:
         set_cm_session(None)
+        self.close()
 
 
 # Default session
-_DEFAULT_SESSION: ContextVar[Optional[Session]] = ContextVar(
-    "_DEFAULT_SESSION", default=None
-)
+_DEFAULT_SESSION: ContextVar[Optional[Session]] = ContextVar("_DEFAULT_SESSION", default=None)
 _IN_SESSION_CM: ContextVar[bool] = ContextVar("_IN_SESSION_CM", default=False)
 
 
@@ -255,36 +327,6 @@ def set_cm_session(session: Optional[Session]) -> None:
     _IN_SESSION_CM.set(session is not None)
 
 
-def get_default_session(
-    service: Optional[QiskitRuntimeService] = None,
-    backend: Optional[Union[str, IBMBackend]] = None,
-) -> Session:
-    """Return the default session.
-
-    Args:
-        service: Service to use to create a default session.
-        backend: Backend for the default session.
-    """
-    backend_name = backend.name if isinstance(backend, IBMBackend) else backend
-
-    session = _DEFAULT_SESSION.get()
-    if (  # pylint: disable=too-many-boolean-expressions
-        session is None
-        or not session._active
-        or (backend_name is not None and session._backend != backend_name)
-        or (service is not None and session.service.channel != service.channel)
-    ):
-        # Create a new session if one doesn't exist, or if the user wants to switch backend/channel.
-        # Close the session only if all jobs are finished and you don't need to run more in the session.
-        if session and not _IN_SESSION_CM.get() and session._active:
-            session.close()
-        if service is None:
-            service = (
-                backend.service
-                if isinstance(backend, IBMBackend)
-                else QiskitRuntimeService()
-            )
-        session = Session(service=service, backend=backend)
-        if not _IN_SESSION_CM.get():
-            _DEFAULT_SESSION.set(session)
-    return session
+def get_cm_session() -> Session:
+    """Return the context managed session."""
+    return _DEFAULT_SESSION.get()
