@@ -28,10 +28,8 @@ def production_only(func):
 
     @wraps(func)
     def _wrapper(self, *args, **kwargs):
-        if "dev" in self.dependencies.url:
-            raise SkipTest(
-                f"Skipping integration test. {self} is not supported on staging."
-            )
+        if "dev" in self.dependencies.url or "test" in self.dependencies.url:
+            raise SkipTest(f"Skipping integration test. {self} is not supported on staging.")
         func(self, *args, **kwargs)
 
     return _wrapper
@@ -56,9 +54,7 @@ def run_quantum_and_cloud_fake(func):
 
     @wraps(func)
     def _wrapper(self, *args, **kwargs):
-        ibm_quantum_service = FakeRuntimeService(
-            channel="ibm_quantum", token="my_token", instance="h/g/p"
-        )
+        ibm_quantum_service = FakeRuntimeService(channel="ibm_quantum", token="my_token")
         cloud_service = FakeRuntimeService(
             channel="ibm_cloud",
             token="my_token",
@@ -78,9 +74,7 @@ def _get_integration_test_config():
         os.getenv("QISKIT_IBM_URL"),
         os.getenv("QISKIT_IBM_INSTANCE"),
     )
-    channel: Any = (
-        "ibm_quantum" if url.find("quantum-computing.ibm.com") >= 0 else "ibm_cloud"
-    )
+    channel: Any = "ibm_quantum" if url.find("quantum-computing.ibm.com") >= 0 else "ibm_cloud"
     return channel, token, url, instance
 
 
@@ -118,14 +112,12 @@ def integration_test_setup(
         @wraps(func)
         def _wrapper(self, *args, **kwargs):
             _supported_channel = (
-                ["ibm_cloud", "ibm_quantum"]
-                if supported_channel is None
-                else supported_channel
+                ["ibm_cloud", "ibm_quantum"] if supported_channel is None else supported_channel
             )
 
             channel, token, url, instance = _get_integration_test_config()
             if not all([channel, token, url]):
-                raise Exception("Configuration Issue")
+                raise Exception("Configuration Issue")  # pylint: disable=broad-exception-raised
 
             if channel not in _supported_channel:
                 raise SkipTest(
@@ -135,7 +127,10 @@ def integration_test_setup(
             service = None
             if init_service:
                 service = QiskitRuntimeService(
-                    channel=channel, token=token, url=url, instance=instance
+                    instance=instance,
+                    channel=channel,
+                    token=token,
+                    url=url,
                 )
             dependencies = IntegrationTestDependencies(
                 channel=channel,
