@@ -21,9 +21,9 @@ from contextlib import suppress
 from collections import defaultdict
 from typing import DefaultDict, Dict
 
+from qiskit.test.reference_circuits import ReferenceCircuits
 from qiskit_ibm_runtime import QISKIT_IBM_RUNTIME_LOGGER_NAME
-from qiskit_ibm_runtime.exceptions import IBMNotAuthorizedError
-from qiskit_ibm_runtime import QiskitRuntimeService
+from qiskit_ibm_runtime import QiskitRuntimeService, Sampler, Options
 
 from .utils import setup_test_logging
 from .decorators import IntegrationTestDependencies, integration_test_setup
@@ -63,9 +63,7 @@ class IBMTestCase(unittest.TestCase):
                     os.getenv("LOG_LEVEL"),
                     str(ex),
                 )
-        if not any(
-            isinstance(handler, logging.StreamHandler) for handler in logger.handlers
-        ):
+        if not any(isinstance(handler, logging.StreamHandler) for handler in logger.handlers):
             logger.addHandler(logging.StreamHandler())
             logger.propagate = False
 
@@ -95,7 +93,8 @@ class IBMIntegrationTestCase(IBMTestCase):
         service = self.service
         for prog in self.to_delete[service.channel]:
             with suppress(Exception):
-                service.delete_program(prog)
+                if "qiskit-test" in prog:
+                    service.delete_program(prog)
 
         # Cancel and delete jobs.
         for job in self.to_cancel[service.channel]:
@@ -133,7 +132,10 @@ class IBMIntegrationJobTestCase(IBMIntegrationTestCase):
         # pylint: disable=arguments-differ
         # pylint: disable=no-value-for-parameter
         super().setUpClass()
-        cls._create_default_program()
+        cls.program_ids = {}
+        cls.sim_backends = {}
+        service = cls.service
+        cls.program_ids[service.channel] = "sampler"
         cls._find_sim_backends()
 
     @classmethod
@@ -143,43 +145,26 @@ class IBMIntegrationJobTestCase(IBMIntegrationTestCase):
         # Delete default program.
         with suppress(Exception):
             service = cls.service
-            service.delete_program(cls.program_ids[service.channel])
-            cls.log.debug(
-                "Deleted %s program %s",
-                service.channel,
-                cls.program_ids[service.channel],
-            )
-
-    @classmethod
-    def _create_default_program(cls):
-        """Create a default program."""
-        metadata = copy.deepcopy(RUNTIME_PROGRAM_METADATA)
-        metadata["name"] = PROGRAM_PREFIX
-        cls.program_ids = {}
-        cls.sim_backends = {}
-        service = cls.service
-        try:
-            prog_id = service.upload_program(data=RUNTIME_PROGRAM, metadata=metadata)
-            cls.log.debug("Uploaded %s program %s", service.channel, prog_id)
-            cls.program_ids[service.channel] = prog_id
-        except IBMNotAuthorizedError:
-            raise unittest.SkipTest("No upload access.")
+            if "qiskit-test" in cls.program_ids[service.channel]:
+                service.delete_program(cls.program_ids[service.channel])
+                cls.log.debug(
+                    "Deleted %s program %s",
+                    service.channel,
+                    cls.program_ids[service.channel],
+                )
 
     @classmethod
     def _find_sim_backends(cls):
         """Find a simulator backend for each service."""
-        cls.sim_backends[cls.service.channel] = cls.service.backends(simulator=True)[
-            0
-        ].name
+        cls.sim_backends[cls.service.channel] = cls.service.backends(simulator=True)[0].name
 
     def _run_program(
         self,
         service,
         program_id=None,
-        iterations=1,
         inputs=None,
         interim_results=None,
-        final_result=None,
+        circuits=None,
         callback=None,
         backend=None,
         log_level=None,
@@ -187,7 +172,6 @@ class IBMIntegrationJobTestCase(IBMIntegrationTestCase):
         max_execution_time=None,
         session_id=None,
         start_session=False,
-        sleep_per_iteration=0,
     ):
         """Run a program."""
         self.log.debug("Running program on %s", service.channel)
@@ -195,30 +179,38 @@ class IBMIntegrationJobTestCase(IBMIntegrationTestCase):
             inputs
             if inputs is not None
             else {
-                "iterations": iterations,
                 "interim_results": interim_results or {},
-                "final_result": final_result or {},
-                "sleep_per_iteration": sleep_per_iteration,
+                "circuits": circuits or ReferenceCircuits.bell(),
             }
         )
         pid = program_id or self.program_ids[service.channel]
-        backend_name = (
-            backend if backend is not None else self.sim_backends[service.channel]
-        )
+        backend_name = backend if backend is not None else self.sim_backends[service.channel]
         options = {
             "backend": backend_name,
             "log_level": log_level,
             "job_tags": job_tags,
             "max_execution_time": max_execution_time,
         }
-        job = service.run(
-            program_id=pid,
-            inputs=inputs,
-            options=options,
-            session_id=session_id,
-            callback=callback,
-            start_session=start_session,
-        )
+        if pid == "sampler":
+            backend = service.get_backend(backend_name)
+            options = Options()
+            if log_level:
+                options.environment.log_level = log_level
+            if job_tags:
+                options.environment.job_tags = job_tags
+            if max_execution_time:
+                options.max_execution_time = max_execution_time
+            sampler = Sampler(backend=backend, options=options)
+            job = sampler.run(circuits or ReferenceCircuits.bell(), callback=callback)
+        else:
+            job = service.run(
+                program_id=pid,
+                inputs=inputs,
+                options=options,
+                session_id=session_id,
+                callback=callback,
+                start_session=start_session,
+            )
         self.log.info("Runtime job %s submitted.", job.job_id())
         self.to_cancel[service.channel].append(job)
         return job
