@@ -17,12 +17,14 @@ import urllib
 
 from requests.exceptions import ProxyError
 
+from qiskit_ibm_provider.proxies import ProxyConfiguration
+from qiskit_ibm_provider.api.exceptions import RequestsApiError as ProviderRequestsApiError
 from qiskit_ibm_runtime import QiskitRuntimeService
 from qiskit_ibm_runtime.api.client_parameters import ClientParameters
 from qiskit_ibm_runtime.api.clients import AuthClient, VersionClient
 from qiskit_ibm_runtime.api.clients.runtime import RuntimeClient
-from qiskit_ibm_runtime.api.exceptions import RequestsApiError
-from qiskit_ibm_runtime.proxies import ProxyConfiguration
+from qiskit_ibm_runtime.api.exceptions import RequestsApiError as RuntimeRequestsApiError
+
 from ..ibm_test_case import IBMTestCase
 from ..decorators import IntegrationTestDependencies, integration_test_setup
 
@@ -56,9 +58,7 @@ class TestProxies(IBMTestCase):
             self.proxy_process.wait()
 
     @integration_test_setup(supported_channel=["ibm_cloud"])
-    def test_proxies_cloud_runtime_client(
-        self, dependencies: IntegrationTestDependencies
-    ) -> None:
+    def test_proxies_cloud_runtime_client(self, dependencies: IntegrationTestDependencies) -> None:
         """Should reach the proxy using RuntimeClient."""
         # pylint: disable=unused-argument
         params = dependencies.service._client_params
@@ -84,7 +84,7 @@ class TestProxies(IBMTestCase):
         service.programs(limit=1)
 
         auth_line = pproxy_desired_access_log_line(dependencies.url)
-        api_line = list(service._hgps.values())[0]._api_client._session.base_url
+        api_line = list(service._hgps.values())[0]._runtime_client._session.base_url
         api_line = pproxy_desired_access_log_line(api_line)
         self.proxy_process.terminate()  # kill to be able of reading the output
         proxy_output = self.proxy_process.stdout.read().decode("utf-8")
@@ -95,9 +95,7 @@ class TestProxies(IBMTestCase):
         self.assertIn(api_line, proxy_output)
 
     @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
-    def test_proxies_account_client(
-        self, dependencies: IntegrationTestDependencies
-    ) -> None:
+    def test_proxies_account_client(self, dependencies: IntegrationTestDependencies) -> None:
         """Should reach the proxy using AccountClient."""
         service = QiskitRuntimeService(
             channel="ibm_quantum",
@@ -109,7 +107,7 @@ class TestProxies(IBMTestCase):
         self.proxy_process.terminate()  # kill to be able of reading the output
 
         auth_line = pproxy_desired_access_log_line(dependencies.url)
-        api_line = list(service._hgps.values())[0]._api_client._session.base_url
+        api_line = list(service._hgps.values())[0]._runtime_client._session.base_url
         api_line = pproxy_desired_access_log_line(api_line)
         proxy_output = self.proxy_process.stdout.read().decode("utf-8")
 
@@ -119,13 +117,9 @@ class TestProxies(IBMTestCase):
         self.assertIn(api_line, proxy_output)
 
     @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
-    def test_proxies_authclient(
-        self, dependencies: IntegrationTestDependencies
-    ) -> None:
+    def test_proxies_authclient(self, dependencies: IntegrationTestDependencies) -> None:
         """Should reach the proxy using AuthClient."""
-        pproxy_desired_access_log_line_ = pproxy_desired_access_log_line(
-            dependencies.url
-        )
+        pproxy_desired_access_log_line_ = pproxy_desired_access_log_line(dependencies.url)
         params = ClientParameters(
             channel="ibm_quantum",
             token=dependencies.token,
@@ -142,13 +136,9 @@ class TestProxies(IBMTestCase):
         )
 
     @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
-    def test_proxies_versionclient(
-        self, dependencies: IntegrationTestDependencies
-    ) -> None:
+    def test_proxies_versionclient(self, dependencies: IntegrationTestDependencies) -> None:
         """Should reach the proxy using IBMVersionFinder."""
-        pproxy_desired_access_log_line_ = pproxy_desired_access_log_line(
-            dependencies.url
-        )
+        pproxy_desired_access_log_line_ = pproxy_desired_access_log_line(dependencies.url)
 
         version_finder = VersionClient(dependencies.url, proxies=VALID_PROXIES)
         version_finder.version()
@@ -170,15 +160,13 @@ class TestProxies(IBMTestCase):
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_PORT_PROXIES),
         )
-        with self.assertRaises(RequestsApiError) as context_manager:
+        with self.assertRaises(RuntimeRequestsApiError) as context_manager:
             client = RuntimeClient(params)
             client.list_programs(limit=1)
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
     @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
-    def test_invalid_proxy_port_authclient(
-        self, dependencies: IntegrationTestDependencies
-    ) -> None:
+    def test_invalid_proxy_port_authclient(self, dependencies: IntegrationTestDependencies) -> None:
         """Should raise RequestApiError with ProxyError using AuthClient."""
         params = ClientParameters(
             channel="ibm_quantum",
@@ -186,7 +174,7 @@ class TestProxies(IBMTestCase):
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_PORT_PROXIES),
         )
-        with self.assertRaises(RequestsApiError) as context_manager:
+        with self.assertRaises(ProviderRequestsApiError) as context_manager:
             _ = AuthClient(params)
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
@@ -196,10 +184,8 @@ class TestProxies(IBMTestCase):
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using VersionClient."""
-        with self.assertRaises(RequestsApiError) as context_manager:
-            version_finder = VersionClient(
-                dependencies.url, proxies=INVALID_PORT_PROXIES
-            )
+        with self.assertRaises(ProviderRequestsApiError) as context_manager:
+            version_finder = VersionClient(dependencies.url, proxies=INVALID_PORT_PROXIES)
             version_finder.version()
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
@@ -215,7 +201,7 @@ class TestProxies(IBMTestCase):
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_ADDRESS_PROXIES),
         )
-        with self.assertRaises(RequestsApiError) as context_manager:
+        with self.assertRaises(RuntimeRequestsApiError) as context_manager:
             client = RuntimeClient(params)
             client.list_programs(limit=1)
 
@@ -232,7 +218,7 @@ class TestProxies(IBMTestCase):
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_ADDRESS_PROXIES),
         )
-        with self.assertRaises(RequestsApiError) as context_manager:
+        with self.assertRaises(ProviderRequestsApiError) as context_manager:
             _ = AuthClient(params)
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
@@ -242,10 +228,8 @@ class TestProxies(IBMTestCase):
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using VersionClient."""
-        with self.assertRaises(RequestsApiError) as context_manager:
-            version_finder = VersionClient(
-                dependencies.url, proxies=INVALID_ADDRESS_PROXIES
-            )
+        with self.assertRaises(ProviderRequestsApiError) as context_manager:
+            version_finder = VersionClient(dependencies.url, proxies=INVALID_ADDRESS_PROXIES)
             version_finder.version()
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
@@ -266,9 +250,7 @@ class TestProxies(IBMTestCase):
                     url=dependencies.url,
                     proxies=ProxyConfiguration(urls={"https": proxy_url}),
                 )
-                version_finder = VersionClient(
-                    params.url, **params.connection_parameters()
-                )
+                version_finder = VersionClient(params.url, **params.connection_parameters())
                 version_finder.version()
 
 
