@@ -14,39 +14,41 @@
 
 import sys
 import copy
-import json
-from unittest.mock import MagicMock, patch, ANY
+import os
+from unittest.mock import MagicMock, patch
 import warnings
 from dataclasses import asdict
 from typing import Dict
-import unittest
 
+from qiskit import transpile
 from qiskit.circuit import QuantumCircuit
-from qiskit.circuit.library import RealAmplitudes
 from qiskit.test.reference_circuits import ReferenceCircuits
 from qiskit.quantum_info import SparsePauliOp
-from qiskit.primitives.utils import _circuit_key
+from qiskit.providers.fake_provider import FakeManila
 
 from qiskit_ibm_runtime import (
     Sampler,
     Estimator,
     Options,
     Session,
-    RuntimeEncoder,
 )
 from qiskit_ibm_runtime.ibm_backend import IBMBackend
 import qiskit_ibm_runtime.session as session_pkg
-from qiskit_ibm_runtime.utils.utils import _hash
 
 from ..ibm_test_case import IBMTestCase
-from ..utils import dict_paritally_equal, flat_dict_partially_equal, dict_keys_equal
-from .mock.fake_runtime_service import FakeRuntimeService
+from ..utils import (
+    dict_paritally_equal,
+    flat_dict_partially_equal,
+    dict_keys_equal,
+    create_faulty_backend,
+)
 
 
 class MockSession(Session):
     """Mock for session class"""
 
     _circuits_map: Dict[str, QuantumCircuit] = {}
+    _instance = None
 
 
 class TestPrimitives(IBMTestCase):
@@ -62,32 +64,6 @@ class TestPrimitives(IBMTestCase):
         super().tearDown()
         session_pkg._DEFAULT_SESSION.set(None)
 
-    def test_skip_transpilation(self):
-        """Test skip_transpilation is hornored."""
-        primitives = [Sampler, Estimator]
-        for cls in primitives:
-            with self.subTest(primitive=cls):
-                inst = cls(session=MagicMock(spec=MockSession), skip_transpilation=True)
-                self.assertTrue(
-                    inst.options.get("transpilation").get("skip_transpilation")
-                )
-
-    def test_skip_transpilation_overwrite(self):
-        """Test overwriting skip_transpilation."""
-        options = Options()
-        options.transpilation.skip_transpilation = False
-        primitives = [Sampler, Estimator]
-        for cls in primitives:
-            with self.subTest(primitive=cls):
-                inst = cls(
-                    session=MagicMock(spec=MockSession),
-                    options=options,
-                    skip_transpilation=True,
-                )
-                self.assertFalse(
-                    inst.options.get("transpilation").get("skip_transpilation")
-                )
-
     def test_dict_options(self):
         """Test passing a dictionary as options."""
         options_vars = [
@@ -123,35 +99,13 @@ class TestPrimitives(IBMTestCase):
                     options = {"backend": backend}
                     with warnings.catch_warnings(record=True) as warn:
                         warnings.simplefilter("always")
-                        inst = cls(service=MagicMock(), options=options)
-                        # We'll get 2 deprecation warnings - one for service and one for backend.
-                        # We need service otherwise backend will get ignored.
-                        self.assertEqual(len(warn), 2)
+                        cls(session=MagicMock(spec=MockSession), options=options)
                         self.assertTrue(
                             all(
                                 issubclass(one_warn.category, DeprecationWarning)
                                 for one_warn in warn
                             )
                         )
-                    self.assertEqual(inst.session.backend(), backend_name)
-
-    def test_old_options(self):
-        """Test specifying old runtime options."""
-        primitives = [Sampler, Estimator]
-        session = MagicMock(spec=MockSession)
-        options = [{"log_level": "WARNING"}, {"image": "foo:bar"}]
-
-        for cls in primitives:
-            for opt in options:
-                with self.subTest(primitive=cls, options=opt):
-                    inst = cls(session=session, options=opt)
-                    inst.run(self.qx, observables=self.obs)
-                    _, kwargs = session.run.call_args
-                    run_options = kwargs["options"]
-                    for key, val in opt.items():
-                        self.assertEqual(run_options[key], val)
-                    inputs = kwargs["inputs"]
-                    self.assertTrue(all(key not in inputs.keys() for key in opt))
 
     def test_runtime_options(self):
         """Test RuntimeOptions specified as primitive options."""
@@ -184,57 +138,114 @@ class TestPrimitives(IBMTestCase):
                 options.transpilation.skip_transpilation = True
                 inst = cls(session=MagicMock(spec=MockSession), options=options)
                 options.transpilation.skip_transpilation = False
-                self.assertTrue(
-                    inst.options.get("transpilation").get("skip_transpilation")
-                )
+                self.assertTrue(inst.options.get("transpilation").get("skip_transpilation"))
 
-    @patch("qiskit_ibm_runtime.session.Session")
-    @patch("qiskit_ibm_runtime.session.QiskitRuntimeService")
-    def test_default_session(self, *_):
-        """Test a session is created if not passed in."""
-        try:
-            sampler = Sampler()
-            self.assertIsNotNone(sampler.session)
-            estimator = Estimator()
-            self.assertEqual(estimator.session, sampler.session)
-        finally:
-            # Ensure it's cleaned up or next test will fail.
-            session_pkg._DEFAULT_SESSION.set(None)
-
-    def test_default_session_after_close(self):
-        """Test a new default session is open after previous is closed."""
-        service = MagicMock()
-        sampler = Sampler(service=service)
-        sampler.session.close()
-        estimator = Estimator(service=service)
-        self.assertIsNotNone(estimator.session)
-        self.assertTrue(estimator.session._active)
-        self.assertNotEqual(estimator.session, sampler.session)
-
-    @patch("qiskit_ibm_runtime.session.Session")
-    @patch("qiskit_ibm_runtime.session.QiskitRuntimeService")
-    def test_backend_str_as_session(self, _, mock_session):
-        """Test specifying a backend name as session."""
+    def test_init_with_backend_str(self):
+        """Test initializing a primitive with a backend name."""
         primitives = [Sampler, Estimator]
         backend_name = "ibm_gotham"
 
         for cls in primitives:
-            with self.subTest(primitive=cls):
-                _ = cls(session=backend_name)
-                mock_session.assert_called_with(service=ANY, backend=backend_name)
+            with self.subTest(primitive=cls), patch(
+                "qiskit_ibm_runtime.base_primitive.QiskitRuntimeService"
+            ) as mock_service:
+                mock_service.reset_mock()
+                mock_service_inst = MagicMock()
+                mock_service.return_value = mock_service_inst
+                mock_backend = MagicMock()
+                mock_backend.name = backend_name
+                mock_service.global_service = None
+                mock_service_inst.backend.return_value = mock_backend
 
-    def test_backend_as_session(self):
-        """Test specifying a backend as session."""
+                inst = cls(backend=backend_name)
+                mock_service.assert_called_once()
+                self.assertIsNone(inst.session)
+                inst.run(self.qx, observables=self.obs)
+                mock_service_inst.run.assert_called_once()
+                runtime_options = mock_service_inst.run.call_args.kwargs["options"]
+                self.assertEqual(runtime_options["backend"], backend_name)
+
+    def test_init_with_session_backend_str(self):
+        """Test initializing a primitive with a backend name using session."""
         primitives = [Sampler, Estimator]
-        backend = MagicMock(spec=IBMBackend)
-        backend._instance = None
+        backend_name = "ibm_gotham"
+
+        for cls in primitives:
+            with self.subTest(primitive=cls), patch(
+                "qiskit_ibm_runtime.base_primitive.QiskitRuntimeService"
+            ):
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=backend_name)
+                    self.assertIsNone(inst.session)
+                self.assertIn("session must be of type Session or None", str(exc.exception))
+
+    def test_init_with_backend_instance(self):
+        """Test initializing a primitive with a backend instance."""
+        primitives = [Sampler, Estimator]
+        service = MagicMock()
+        model_backend = FakeManila()
+        backend = IBMBackend(
+            configuration=model_backend.configuration(), service=service, api_client=MagicMock()
+        )
         backend.name = "ibm_gotham"
-        backend.service = MagicMock()
 
         for cls in primitives:
             with self.subTest(primitive=cls):
-                inst = cls(session=backend)
-                self.assertEqual(inst.session.backend(), backend.name)
+                service.reset_mock()
+                inst = cls(backend=backend)
+                self.assertIsNone(inst.session)
+                inst.run(self.qx, observables=self.obs)
+                service.run.assert_called_once()
+                runtime_options = service.run.call_args.kwargs["options"]
+                self.assertEqual(runtime_options["backend"], backend.name)
+
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=backend)
+                    self.assertIsNone(inst.session)
+                self.assertIn("session must be of type Session or None", str(exc.exception))
+
+    def test_init_with_backend_session(self):
+        """Test initializing a primitive with both backend and session."""
+        primitives = [Sampler, Estimator]
+        session = MagicMock(spec=MockSession)
+        backend_name = "ibm_gotham"
+
+        for cls in primitives:
+            with self.subTest(primitive=cls):
+                session.reset_mock()
+                inst = cls(session=session, backend=backend_name)
+                self.assertIsNotNone(inst.session)
+                inst.run(self.qx, observables=self.obs)
+                session.run.assert_called_once()
+
+    def test_init_with_no_backend_session_cloud(self):
+        """Test initializing a primitive without backend or session for cloud channel."""
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            with self.subTest(primitive=cls), patch(
+                "qiskit_ibm_runtime.base_primitive.QiskitRuntimeService"
+            ) as mock_service:
+                mock_service_inst = MagicMock()
+                mock_service_inst.channel = "ibm_cloud"
+                mock_service.return_value = mock_service_inst
+                mock_service.reset_mock()
+                mock_service.global_service = None
+                inst = cls()
+                mock_service.assert_called_once()
+                self.assertIsNone(inst.session)
+
+    def test_init_with_no_backend_session_quantum(self):
+        """Test initializing a primitive without backend or session for quantum channel."""
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            with self.subTest(primitive=cls), patch(
+                "qiskit_ibm_runtime.base_primitive.QiskitRuntimeService"
+            ) as mock_service:
+                mock_service.reset_mock()
+                with self.assertRaises(ValueError):
+                    _ = cls()
 
     def test_default_session_context_manager(self):
         """Test getting default session within context manager."""
@@ -251,35 +262,55 @@ class TestPrimitives(IBMTestCase):
 
     def test_default_session_cm_new_backend(self):
         """Test using a different backend within context manager."""
-        service = MagicMock()
-        backend = MagicMock(spec=IBMBackend)
-        backend._instance = None
-        backend.name = "ibm_gotham"
-        backend.service = service
         cm_backend = "ibm_metropolis"
         primitives = [Sampler, Estimator]
-
+        model_backend = FakeManila()
         for cls in primitives:
             with self.subTest(primitive=cls):
-                with Session(service=service, backend=cm_backend) as session:
-                    inst = cls(session=backend)
-                    self.assertNotEqual(inst.session, session)
-                    self.assertEqual(inst.session.backend(), backend.name)
-                    self.assertEqual(session.backend(), cm_backend)
-                    self.assertTrue(session._active)
-                    inst2 = cls()
-                    self.assertEqual(inst2.session, session)
-                    session.close()
-                self.assertFalse(session._active)
+                service = MagicMock()
+                backend = IBMBackend(
+                    configuration=model_backend.configuration(),
+                    service=service,
+                    api_client=MagicMock(),
+                )
+                backend.name = "ibm_gotham"
+
+                with Session(service=service, backend=cm_backend):
+                    inst = cls(backend=backend)
+                    self.assertIsNone(inst.session)
+                    inst.run(self.qx, observables=self.obs)
+                    service.run.assert_called_once()
+                    runtime_options = service.run.call_args.kwargs["options"]
+                    self.assertEqual(runtime_options["backend"], backend.name)
+
+    def test_no_session(self):
+        """Test running without session."""
+        primitives = [Sampler, Estimator]
+        model_backend = FakeManila()
+        for cls in primitives:
+            with self.subTest(primitive=cls):
+                service = MagicMock()
+                backend = IBMBackend(
+                    configuration=model_backend.configuration(),
+                    service=service,
+                    api_client=MagicMock(),
+                )
+                inst = cls(backend)
+                inst.run(self.qx, observables=self.obs)
+                self.assertIsNone(inst.session)
+                service.run.assert_called_once()
+                kwargs_list = service.run.call_args.kwargs
+                self.assertNotIn("session_id", kwargs_list)
+                self.assertNotIn("start_session", kwargs_list)
 
     def test_run_default_options(self):
         """Test run using default options."""
         session = MagicMock(spec=MockSession)
         options_vars = [
-            (Options(resilience_level=9), {"resilience_settings": {"level": 9}}),
+            (Options(resilience_level=1), {"resilience_settings": {"level": 1}}),
             (
-                Options(optimization_level=8),
-                {"transpilation_settings": {"optimization_settings": {"level": 8}}},
+                Options(optimization_level=3),
+                {"transpilation_settings": {"optimization_settings": {"level": 3}}},
             ),
             (
                 {
@@ -323,9 +354,7 @@ class TestPrimitives(IBMTestCase):
                     inputs,
                     {
                         "resilience_settings": {"level": 1},
-                        "transpilation_settings": {
-                            "optimization_settings": {"level": 2}
-                        },
+                        "transpilation_settings": {"optimization_settings": {"level": 2}},
                         "run_options": {"shots": 99},
                     },
                 )
@@ -334,17 +363,17 @@ class TestPrimitives(IBMTestCase):
         """Test run using overwritten options."""
         session = MagicMock(spec=MockSession)
         options_vars = [
-            ({"resilience_level": 9}, {"resilience_settings": {"level": 9}}),
+            ({"resilience_level": 1}, {"resilience_settings": {"level": 1}}),
             ({"shots": 200}, {"run_options": {"shots": 200}}),
             (
-                {"optimization_level": 8},
-                {"transpilation_settings": {"optimization_settings": {"level": 8}}},
+                {"optimization_level": 3},
+                {"transpilation_settings": {"optimization_settings": {"level": 3}}},
             ),
             (
-                {"initial_layout": [1, 2], "optimization_level": 8},
+                {"initial_layout": [1, 2], "optimization_level": 2},
                 {
                     "transpilation_settings": {
-                        "optimization_settings": {"level": 8},
+                        "optimization_settings": {"level": 2},
                         "initial_layout": [1, 2],
                     }
                 },
@@ -428,9 +457,7 @@ class TestPrimitives(IBMTestCase):
                 inst.run(self.qx, observables=self.obs, shots=200)
                 kwargs_list = session.run.call_args_list
                 for idx, shots in zip([0, 1], [100, 200]):
-                    self.assertEqual(
-                        kwargs_list[idx][1]["inputs"]["run_options"]["shots"], shots
-                    )
+                    self.assertEqual(kwargs_list[idx][1]["inputs"]["run_options"]["shots"], shots)
                 self.assertDictEqual(inst.options.__dict__, asdict(Options()))
 
     def test_run_same_session(self):
@@ -444,62 +471,6 @@ class TestPrimitives(IBMTestCase):
             inst.run(self.qx, observables=self.obs)
         self.assertEqual(session.run.call_count, num_runs)
 
-    @unittest.skip("Skip until data caching is reenabled.")
-    def test_primitives_circuit_caching(self):
-        """Test circuit caching in Estimator and Sampler classes"""
-        psi1 = RealAmplitudes(num_qubits=2, reps=2)
-        psi1.measure_all()
-        psi2 = RealAmplitudes(num_qubits=2, reps=3)
-        psi2.measure_all()
-        psi3 = RealAmplitudes(num_qubits=2, reps=2)
-        psi3.measure_all()
-        psi4 = RealAmplitudes(num_qubits=2, reps=3)
-        psi4.measure_all()
-        psi1_id = _hash(json.dumps(_circuit_key(psi1), cls=RuntimeEncoder))
-        psi2_id = _hash(json.dumps(_circuit_key(psi2), cls=RuntimeEncoder))
-        psi3_id = _hash(json.dumps(_circuit_key(psi3), cls=RuntimeEncoder))
-        psi4_id = _hash(json.dumps(_circuit_key(psi4), cls=RuntimeEncoder))
-
-        # pylint: disable=invalid-name
-        H1 = SparsePauliOp.from_list([("II", 1), ("IZ", 2), ("XI", 3)])
-        H2 = SparsePauliOp.from_list([("IZ", 1)])
-
-        with Session(
-            service=FakeRuntimeService(channel="ibm_quantum", token="abc"),
-            backend="ibmq_qasm_simulator",
-        ) as session:
-            estimator = Estimator(session=session)
-
-            # calculate [ <psi1(theta1)|H1|psi1(theta1)> ]
-            with patch.object(estimator._session, "run") as mock_run:
-                estimator.run([psi1, psi2], [H1, H2], [[1] * 6, [1] * 8])
-                _, kwargs = mock_run.call_args
-                inputs = kwargs["inputs"]
-                self.assertDictEqual(inputs["circuits"], {psi1_id: psi1, psi2_id: psi2})
-                self.assertEqual(inputs["circuit_ids"], [psi1_id, psi2_id])
-
-            sampler = Sampler(session=session)
-            with patch.object(sampler._session, "run") as mock_run:
-                sampler.run([psi1, psi2], [[1] * 6, [1] * 8])
-                _, kwargs = mock_run.call_args
-                inputs = kwargs["inputs"]
-                self.assertDictEqual(inputs["circuits"], {})
-                self.assertEqual(inputs["circuit_ids"], [psi1_id, psi2_id])
-
-            with patch.object(estimator._session, "run") as mock_run:
-                estimator.run([psi3], [H1], [[1] * 6])
-                _, kwargs = mock_run.call_args
-                inputs = kwargs["inputs"]
-                self.assertDictEqual(inputs["circuits"], {psi3_id: psi3})
-                self.assertEqual(inputs["circuit_ids"], [psi3_id])
-
-            with patch.object(sampler._session, "run") as mock_run:
-                sampler.run([psi4, psi1], [[1] * 8, [1] * 6])
-                _, kwargs = mock_run.call_args
-                inputs = kwargs["inputs"]
-                self.assertDictEqual(inputs["circuits"], {psi4_id: psi4})
-                self.assertEqual(inputs["circuit_ids"], [psi4_id, psi1_id])
-
     def test_set_options(self):
         """Test set options."""
         options = Options(optimization_level=1, execution={"shots": 100})
@@ -539,7 +510,7 @@ class TestPrimitives(IBMTestCase):
             {"shots": 10},
             {"seed_simulator": 123},
             {"skip_transpilation": True, "log_level": "ERROR"},
-            {"initial_layout": [1, 2], "shots": 100, "noise_amplifier": "CxAmplifier"},
+            {"initial_layout": [1, 2], "shots": 100, "noise_factors": (0, 2, 4)},
         ]
 
         expected_list = [Options(), Options(), Options(), Options(), Options()]
@@ -549,7 +520,7 @@ class TestPrimitives(IBMTestCase):
         expected_list[3].environment.log_level = "ERROR"
         expected_list[4].transpilation.initial_layout = [1, 2]
         expected_list[4].execution.shots = 100
-        expected_list[4].resilience.noise_amplifier = "CxAmplifier"
+        expected_list[4].resilience.noise_factors = (0, 2, 4)
 
         session = MagicMock(spec=MockSession)
         primitives = [Sampler, Estimator]
@@ -582,7 +553,12 @@ class TestPrimitives(IBMTestCase):
                     simulator={"noise_model": "foo"},
                 )
                 inst = cls(session=session, options=options)
-                inst.run(self.qx, observables=self.obs)
+
+                if isinstance(inst, Estimator):
+                    inst.run(self.qx, observables=self.obs)
+                else:
+                    inst.run(self.qx)
+
                 if sys.version_info >= (3, 8):
                     inputs = session.run.call_args.kwargs["inputs"]
                 else:
@@ -628,6 +604,291 @@ class TestPrimitives(IBMTestCase):
                 )
                 self.assertEqual(inputs["resilience_settings"]["level"], 0)
 
+    def test_resilience_options(self):
+        """Test resilience options."""
+        options_dicts = [
+            {"resilience": {"extrapolator": "NoExtrapolator"}},
+            {
+                "resilience": {
+                    "extrapolator": "QuarticExtrapolator",
+                    "noise_factors": [1, 2, 3, 4],
+                },
+            },
+            {
+                "resilience": {
+                    "extrapolator": "CubicExtrapolator",
+                    "noise_factors": [1, 2, 3],
+                },
+            },
+        ]
+        session = MagicMock(spec=MockSession)
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            for opts_dict in options_dicts:
+                # When this environment variable is set, validation is turned off
+                try:
+                    os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"] = "1"
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                finally:
+                    # Delete environment variable to validate input
+                    del os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"]
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                self.assertIn(list(opts_dict["resilience"].values())[0], str(exc.exception))
+                if len(opts_dict["resilience"].keys()) > 1:
+                    self.assertIn(list(opts_dict["resilience"].keys())[1], str(exc.exception))
+
+    def test_environment_options(self):
+        """Test environment options."""
+        options_dicts = [
+            {"environment": {"log_level": "NoLogLevel"}},
+        ]
+        session = MagicMock(spec=MockSession)
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            for opts_dict in options_dicts:
+                # When this environment variable is set, validation is turned off
+                try:
+                    os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"] = "1"
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                finally:
+                    # Delete environment variable to validate input
+                    del os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"]
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                self.assertIn(list(opts_dict["environment"].values())[0], str(exc.exception))
+
+    def test_transpilation_options(self):
+        """Test transpilation options."""
+        options_dicts = [
+            {"transpilation": {"layout_method": "NoLayoutMethod"}},
+            {"transpilation": {"routing_method": "NoRoutingMethod"}},
+            {"transpilation": {"approximation_degree": 1.1}},
+        ]
+        session = MagicMock(spec=MockSession)
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            for opts_dict in options_dicts:
+                # When this environment variable is set, validation is turned off
+                try:
+                    os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"] = "1"
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                finally:
+                    # Delete environment variable to validate input
+                    del os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"]
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                self.assertIn(list(opts_dict["transpilation"].keys())[0], str(exc.exception))
+
+    def test_max_execution_time_options(self):
+        """Test transpilation options."""
+        options_dicts = [
+            {"max_execution_time": Options._MAX_EXECUTION_TIME + 1},
+        ]
+        session = MagicMock(spec=MockSession)
+        primitives = [Sampler, Estimator]
+
+        for cls in primitives:
+            for opts_dict in options_dicts:
+                # When this environment variable is set, validation is turned off
+                try:
+                    os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"] = "1"
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                finally:
+                    # Delete environment variable to validate input
+                    del os.environ["QISKIT_RUNTIME_SKIP_OPTIONS_VALIDATION"]
+                with self.assertRaises(ValueError) as exc:
+                    inst = cls(session=session, options=opts_dict)
+                    inst.run(self.qx, observables=self.obs)
+                self.assertIn(
+                    "max_execution_time must be below 28800 seconds",
+                    str(exc.exception),
+                )
+
+    def test_raise_faulty_qubits(self):
+        """Test faulty qubits is raised."""
+        fake_backend = FakeManila()
+        num_qubits = fake_backend.configuration().num_qubits
+        circ = QuantumCircuit(num_qubits, num_qubits)
+        for i in range(num_qubits):
+            circ.x(i)
+        transpiled = transpile(circ, backend=fake_backend)
+        observable = SparsePauliOp("Z" * num_qubits)
+
+        faulty_qubit = 4
+        ibm_backend = create_faulty_backend(fake_backend, faulty_qubit=faulty_qubit)
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with self.assertRaises(ValueError) as err:
+            estimator.run(transpiled, observable, skip_transpilation=True)
+        self.assertIn(f"faulty qubit {faulty_qubit}", str(err.exception))
+
+        transpiled.measure_all()
+        with self.assertRaises(ValueError) as err:
+            sampler.run(transpiled, skip_transpilation=True)
+        self.assertIn(f"faulty qubit {faulty_qubit}", str(err.exception))
+
+    def test_raise_faulty_qubits_many(self):
+        """Test faulty qubits is raised if one circuit uses it."""
+        fake_backend = FakeManila()
+        num_qubits = fake_backend.configuration().num_qubits
+
+        circ1 = QuantumCircuit(1, 1)
+        circ1.x(0)
+        circ2 = QuantumCircuit(num_qubits, num_qubits)
+        for i in range(num_qubits):
+            circ2.x(i)
+        transpiled = transpile([circ1, circ2], backend=fake_backend)
+        observable = SparsePauliOp("Z" * num_qubits)
+
+        faulty_qubit = 4
+        ibm_backend = create_faulty_backend(fake_backend, faulty_qubit=faulty_qubit)
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with self.assertRaises(ValueError) as err:
+            estimator.run(transpiled, [observable, observable], skip_transpilation=True)
+        self.assertIn(f"faulty qubit {faulty_qubit}", str(err.exception))
+
+        for circ in transpiled:
+            circ.measure_all()
+
+        with self.assertRaises(ValueError) as err:
+            sampler.run(transpiled, skip_transpilation=True)
+        self.assertIn(f"faulty qubit {faulty_qubit}", str(err.exception))
+
+    def test_raise_faulty_edge(self):
+        """Test faulty edge is raised."""
+        fake_backend = FakeManila()
+        num_qubits = fake_backend.configuration().num_qubits
+        circ = QuantumCircuit(num_qubits, num_qubits)
+        for i in range(num_qubits - 2):
+            circ.cx(i, i + 1)
+        transpiled = transpile(circ, backend=fake_backend)
+        observable = SparsePauliOp("Z" * num_qubits)
+
+        edge_qubits = [0, 1]
+        ibm_backend = create_faulty_backend(fake_backend, faulty_edge=("cx", edge_qubits))
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with self.assertRaises(ValueError) as err:
+            estimator.run(transpiled, observable, skip_transpilation=True)
+        self.assertIn("cx", str(err.exception))
+        self.assertIn(f"faulty edge {tuple(edge_qubits)}", str(err.exception))
+
+        transpiled.measure_all()
+        with self.assertRaises(ValueError) as err:
+            sampler.run(transpiled, skip_transpilation=True)
+        self.assertIn("cx", str(err.exception))
+        self.assertIn(f"faulty edge {tuple(edge_qubits)}", str(err.exception))
+
+    def test_faulty_qubit_not_used(self):
+        """Test faulty qubit is not raise if not used."""
+        fake_backend = FakeManila()
+        circ = QuantumCircuit(2, 2)
+        for i in range(2):
+            circ.x(i)
+        transpiled = transpile(circ, backend=fake_backend, initial_layout=[0, 1])
+        observable = SparsePauliOp("Z" * fake_backend.configuration().num_qubits)
+
+        faulty_qubit = 4
+        ibm_backend = create_faulty_backend(fake_backend, faulty_qubit=faulty_qubit)
+
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with patch.object(Session, "run") as mock_run:
+            estimator.run(transpiled, observable, skip_transpilation=True)
+        mock_run.assert_called_once()
+
+        transpiled.measure_active()
+        with patch.object(Session, "run") as mock_run:
+            sampler.run(transpiled, skip_transpilation=True)
+        mock_run.assert_called_once()
+
+    def test_faulty_edge_not_used(self):
+        """Test faulty edge is not raised if not used."""
+        fake_backend = FakeManila()
+        coupling_map = fake_backend.configuration().coupling_map
+
+        circ = QuantumCircuit(2, 2)
+        circ.cx(0, 1)
+
+        transpiled = transpile(circ, backend=fake_backend, initial_layout=coupling_map[0])
+        observable = SparsePauliOp("Z" * fake_backend.configuration().num_qubits)
+
+        edge_qubits = coupling_map[-1]
+        ibm_backend = create_faulty_backend(fake_backend, faulty_edge=("cx", edge_qubits))
+
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with patch.object(Session, "run") as mock_run:
+            estimator.run(transpiled, observable, skip_transpilation=True)
+        mock_run.assert_called_once()
+
+        transpiled.measure_all()
+        with patch.object(Session, "run") as mock_run:
+            sampler.run(transpiled, skip_transpilation=True)
+        mock_run.assert_called_once()
+
+    def test_no_raise_skip_transpilation(self):
+        """Test faulty qubits and edges are not raise if not skipping."""
+        fake_backend = FakeManila()
+        num_qubits = fake_backend.configuration().num_qubits
+        circ = QuantumCircuit(num_qubits, num_qubits)
+        for i in range(num_qubits - 2):
+            circ.cx(i, i + 1)
+        transpiled = transpile(circ, backend=fake_backend)
+        observable = SparsePauliOp("Z" * num_qubits)
+
+        edge_qubits = [0, 1]
+        ibm_backend = create_faulty_backend(
+            fake_backend, faulty_qubit=0, faulty_edge=("cx", edge_qubits)
+        )
+
+        service = MagicMock()
+        service.backend.return_value = ibm_backend
+        session = Session(service=service, backend=fake_backend.name)
+        sampler = Sampler(session=session)
+        estimator = Estimator(session=session)
+
+        with patch.object(Session, "run") as mock_run:
+            estimator.run(transpiled, observable)
+        mock_run.assert_called_once()
+
+        transpiled.measure_all()
+        with patch.object(Session, "run") as mock_run:
+            sampler.run(transpiled)
+        mock_run.assert_called_once()
+
     def _update_dict(self, dict1, dict2):
         for key, val in dict1.items():
             if isinstance(val, dict):
@@ -641,3 +902,68 @@ class TestPrimitives(IBMTestCase):
             dict_paritally_equal(dict1, dict2),
             f"{dict1} and {dict2} not partially equal.",
         )
+
+    def test_qctrl_supported_values_for_options(self):
+        """Test exception when options levels not supported."""
+        no_resilience_options = {
+            "noise_factors": None,
+            "extrapolator": None,
+        }
+
+        options_good = [
+            # Minium working settings
+            {},
+            # No warnings, we need resilience options here because by default they are getting populated.
+            {"resilience": no_resilience_options},
+            # Arbitrary approximation degree (issues warning)
+            {"approximation_degree": 1},
+            # Arbitrary resilience options(issue warning)
+            {
+                "resilience_level": 1,
+                "resilience": {"noise_factors": (1, 1, 3)},
+                "approximation_degree": 1,
+            },
+            # Resilience level > 1 (issue warning)
+            {"resilience_level": 2},
+            # Optimization level = 1,2 (issue warning)
+            {"optimization_level": 1},
+            {"optimization_level": 2},
+            # Skip transpilation level(issue warning)
+            {"skip_transpilation": True},
+        ]
+        session = MagicMock(spec=MockSession)
+        session.service._channel_strategy = "q-ctrl"
+        session.service.backend().configuration().simulator = False
+        primitives = [Sampler, Estimator]
+        for cls in primitives:
+            for options in options_good:
+                with self.subTest(msg=f"{cls}, {options}"):
+                    inst = cls(session=session)
+                    if isinstance(inst, Estimator):
+                        _ = inst.run(self.qx, observables=self.obs, **options)
+                    else:
+                        _ = inst.run(self.qx, **options)
+
+    def test_qctrl_unsupported_values_for_options(self):
+        """Test exception when options levels are not supported."""
+        options_bad = [
+            # Bad resilience levels
+            ({"resilience_level": 0}, "resilience level"),
+            # Bad optimization level
+            ({"optimization_level": 0}, "optimization level"),
+        ]
+        session = MagicMock(spec=MockSession)
+        session.service._channel_strategy = "q-ctrl"
+        session.service.backend().configuration().simulator = False
+        primitives = [Sampler, Estimator]
+        for cls in primitives:
+            for bad_opt, expected_message in options_bad:
+                with self.subTest(msg=bad_opt):
+                    inst = cls(session=session)
+                    with self.assertRaises(ValueError) as exc:
+                        if isinstance(inst, Sampler):
+                            _ = inst.run(self.qx, **bad_opt)
+                        else:
+                            _ = inst.run(self.qx, observables=self.obs, **bad_opt)
+
+                        self.assertIn(expected_message, str(exc.exception))
