@@ -17,11 +17,14 @@ import logging
 import time
 import unittest
 from unittest import mock
-from typing import Dict
+from typing import Dict, Optional, Any
+from datetime import datetime
 
 from qiskit.circuit import QuantumCircuit
 from qiskit.providers.jobstatus import JOB_FINAL_STATES, JobStatus
 from qiskit.providers.exceptions import QiskitBackendNotFoundError
+from qiskit.providers.models import BackendStatus, BackendProperties
+from qiskit.providers.backend import Backend
 from qiskit_ibm_runtime.hub_group_project import HubGroupProject
 from qiskit_ibm_runtime import QiskitRuntimeService
 from qiskit_ibm_runtime.ibm_backend import IBMBackend
@@ -37,9 +40,7 @@ def setup_test_logging(logger: logging.Logger, filename: str) -> None:
         filename: Name of the output file, if log to file is enabled.
     """
     # Set up formatter.
-    log_fmt = "{}.%(funcName)s:%(levelname)s:%(asctime)s:" " %(message)s".format(
-        logger.name
-    )
+    log_fmt = "{}.%(funcName)s:%(levelname)s:%(asctime)s:" " %(message)s".format(logger.name)
     formatter = logging.Formatter(log_fmt)
 
     if os.getenv("STREAM_LOG", "true").lower() == "true":
@@ -133,10 +134,7 @@ def wait_for_status(job, status, poll_time=1, time_out=20):
 def get_real_device(service):
     """Get a real device for the service."""
     try:
-        # TODO: Remove filters when ibmq_berlin is removed
-        return service.least_busy(
-            simulator=False, filters=lambda b: b.name != "ibmq_berlin"
-        ).name
+        return service.least_busy(simulator=False).name
     except QiskitBackendNotFoundError:
         raise unittest.SkipTest("No real device")  # cloud has no real device
 
@@ -194,3 +192,65 @@ def dict_keys_equal(dict1: dict, dict2: dict) -> bool:
                 return False
 
     return True
+
+
+def create_faulty_backend(
+    model_backend: Backend,
+    faulty_qubit: Optional[int] = None,
+    faulty_edge: Optional[tuple] = None,
+) -> IBMBackend:
+    """Create an IBMBackend that has faulty qubits and/or edges.
+
+    Args:
+        model_backend: Fake backend to model after.
+        faulty_qubit: Faulty qubit.
+        faulty_edge: Faulty edge, a tuple of (gate, qubits)
+
+    Returns:
+        An IBMBackend with faulty qubits/edges.
+    """
+
+    properties = model_backend.properties().to_dict()
+
+    if faulty_qubit:
+        properties["qubits"][faulty_qubit].append(
+            {"date": datetime.now(), "name": "operational", "unit": "", "value": 0}
+        )
+
+    if faulty_edge:
+        gate, qubits = faulty_edge
+        for gate_obj in properties["gates"]:
+            if gate_obj["gate"] == gate and gate_obj["qubits"] == qubits:
+                gate_obj["parameters"].append(
+                    {
+                        "date": datetime.now(),
+                        "name": "operational",
+                        "unit": "",
+                        "value": 0,
+                    }
+                )
+
+    out_backend = IBMBackend(
+        configuration=model_backend.configuration(),
+        service=mock.MagicMock(),
+        api_client=None,
+        instance=None,
+    )
+
+    out_backend.status = lambda: BackendStatus(  # type: ignore[assignment]
+        backend_name="foo",
+        backend_version="1.0",
+        operational=True,
+        pending_jobs=0,
+        status_msg="",
+    )
+    out_backend.properties = lambda: BackendProperties.from_dict(properties)  # type: ignore
+    return out_backend
+
+
+def get_mocked_backend(name: str = "ibm_gotham") -> Any:
+    """Return a mock backend."""
+    mock_backend = mock.MagicMock(spec=IBMBackend)
+    mock_backend.name = name
+    mock_backend._instance = None
+    return mock_backend
